#
# spec file for package pandoc
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name pandoc

%bcond_with tests

Name:           pandoc 
Version:        1.17.1
Release:        1.12
Summary:        Conversion between markup formats
License:        GPL-2.0+
Group:          Productivity/Publishing/Other

Url:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
Source1:        pandoc-pdf.readme
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
# Begin cabal-rpm deps:
BuildRequires:  chrpath
BuildRequires:  ghc-HTTP-devel
BuildRequires:  ghc-JuicyPixels-devel
BuildRequires:  ghc-SHA-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-base64-bytestring-devel
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-blaze-html-devel
BuildRequires:  ghc-blaze-markup-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-cmark-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-data-default-devel
BuildRequires:  ghc-deepseq-generics-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-extensible-exceptions-devel
BuildRequires:  ghc-filemanip-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-haddock-library-devel
BuildRequires:  ghc-highlighting-kate-devel
BuildRequires:  ghc-hslua-devel
BuildRequires:  ghc-http-client-devel
BuildRequires:  ghc-http-client-tls-devel
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-network-uri-devel
BuildRequires:  ghc-pandoc-types-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-syb-devel
BuildRequires:  ghc-tagsoup-devel
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-texmath-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-xml-devel
BuildRequires:  ghc-yaml-devel
BuildRequires:  ghc-zip-archive-devel
BuildRequires:  ghc-zlib-devel
%if %{with tests}
BuildRequires:  ghc-Diff-devel
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-ansi-terminal-devel
BuildRequires:  ghc-executable-path-devel
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
BuildRequires:  ghc-test-framework-quickcheck2-devel
%endif
# End cabal-rpm deps
BuildRequires:  fdupes
Suggests:       texlive-latex-bin-bin

%description
Pandoc is a Haskell library for converting from one markup format to another,
and a command-line tool that uses this library. It can read markdown and
(subsets of) HTML, reStructuredText, LaTeX, DocBook, MediaWiki markup, TWiki
markup, Haddock markup, OPML, Emacs Org-Mode, txt2tags and Textile, and it can
write markdown, reStructuredText, XHTML, HTML 5, LaTeX, ConTeXt, DocBook, OPML,
OpenDocument, ODT, Word docx, RTF, MediaWiki, DokuWiki, Textile, groff man
pages, plain text, Emacs Org-Mode, AsciiDoc, Haddock markup, EPUB (v2 and v3),
FictionBook2, InDesign ICML, and several kinds of HTML/javascript slide shows
(S5, Slidy, Slideous, DZSlides, reveal.js).

Pandoc extends standard markdown syntax with footnotes, embedded LaTeX,
definition lists, tables, and other features. A compatibility mode is provided
for those who need a drop-in replacement for Markdown.pl.

In contrast to existing tools for converting markdown to HTML, which use regex
substitutions, pandoc has a modular design: it consists of a set of readers,
which parse text in a given format and produce a native representation of the
document, and a set of writers, which convert this native representation into a
target format. Thus, adding an input or output format requires only adding a
reader or writer.


%package pdf

Summary:        Meta package for support generating pdf with pandoc
Group:          Productivity/Publishing/PDF
Requires:       %{name} = %{version}
Requires:       texlive-latex-bin-bin

%description pdf
Meta package for support generating pdf with pandoc.

%package -n ghc-%{name}
Summary:        Haskell %{name} library
Group:          System/Libraries

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.


%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Group:          Development/Libraries/Other
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}
Requires:       ghc-%{name} = %{version}-%{release}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.

%prep
%setup -q
cp %{SOURCE1} .

%build
%ghc_lib_build

%install
%ghc_lib_install

%ghc_fix_dynamic_rpath %{pkg_name}

# These files will be installed in the standard _docdir
rm %{buildroot}%{_datadir}/%{pkg_name}-%{version}/COPYRIGHT
rm %{buildroot}%{_datadir}/%{pkg_name}-%{version}/README
# Link duplicate template files
%fdupes %{buildroot}%{_datadir}/%{pkg_name}-%{version}/data/templates/

%check
%if %{with tests}
%cabal test
%endif

%post -n ghc-%{name}-devel
%ghc_pkg_recache

%postun -n ghc-%{name}-devel
%ghc_pkg_recache

%files
%defattr(-,root,root,-)
%doc COPYING
%doc README
%doc BUGS CONTRIBUTING.md COPYRIGHT changelog
%{_bindir}/%{name}
%{_datadir}/%{name}-%{version}
%{_mandir}/man1/pandoc.1.*

%files pdf
%defattr(-,root,root,-)
%doc pandoc-pdf.readme

%files -n ghc-%{name} -f ghc-%{name}.files
%defattr(-,root,root,-)
%doc COPYING

%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%defattr(-,root,root,-)
%doc README

%changelog
* Sun Jun  5 2016 mimi.vx@gmail.com
- update to 1.17.1
  * New output format: `docbook5`
  * `Text.Pandoc.Options`: Add `writerDocBook5` to `WriterOptions`
  * Org writer:
  + Add :PROPERTIES: drawer support
    This allows header attributes to be added to org documents in the form
    of `:PROPERTIES:` drawers.  All available attributes are stored as
    key/value pairs.  This reflects the way the org reader handles
    `:PROPERTIES:` blocks.
  + Add drawer capability. For the implementation of the
    Drawer element in the Org Writer, we make use of a generic Block
    container with attributes.  The presence of a `drawer` class defines
    that the `Div` constructor is a drawer. The first class defines the
    drawer name to use.  The key-value list in the attributes defines
    the keys to add inside the Drawer.  Lastly, the list of Block elements
    contains miscellaneous blocks elements to add inside of the Drawer.
  + Use `CUSTOM_ID` in properties.  The `ID` property is
    reserved for internal use by Org-mode and should not be used.
    The `CUSTOM_ID` property is to be used instead, it is converted to the
    `ID` property for certain export format.
  * LaTeX writer:
  + Ignore `--incremental` unless output format is beamer.
  + Fix polyglossia to babel env mapping.
    Allow for optional argument in square brackets.
  + Recognize `la-x-classic` as Classical Latin.
    This allows one to access the hyphenation patterns in CTAN's
    hyph-utf8.
  + Add missing languages from hyph-utf8.
  + Improve use of `\strut` with `\minipage` inside tables
    .  This improves spacing in multiline
    tables.
  + Use `{}` around options containing special chars.
  + Avoid lazy `foldl`.
  + Don't escape underscore in labels.  Previously they were
    escaped as `ux5f`.
  + brazilian -> brazil for polyglossia.
  * HTML writer: Ensure mathjax link is added when math appears in footnote
  . Previously if a document only had math in a footnote, the
  MathJax link would not be added.
  * EPUB writer: set `navpage` variable on nav page.
  This allows templates to treat it differently.
  * DocBook writer:
  + Use docbook5 if `writerDocbook5` is set.
  + Properly handle `ulink`/`link`.
  * EPUB reader:
  + Unescape URIs in spine.
  + EPUB reader:  normalise link id.
  * Docx Reader:
  + Parse `moveTo` and `moveFrom`.
    `moveTo` and `moveFrom` are track-changes tags that are used when a
    block of text is moved in the document. We now recognize these tags and
    treat them the same as `insert` and `delete`, respectively. So,
    `--track-changes=accept` will show the moved version, while
    `--track-changes=reject` will show the original version.
  + Tests for track-changes moving.
  * ODT, EPUB, Docx readers: throw `PandocError` on unzip failure
  Previously, `readDocx`, `readEPUB`, and `readOdt`
  would error out if zip-archive failed. We change the archive extraction
  step from `toArchive` to `toArchiveOrFail`, which returns an Either value.
  * Markdown, HTML readers:  be more forgiving about unescaped `&` in
  HTML (#2410).  We are now more forgiving about parsing invalid HTML with
  unescaped `&` as raw HTML.  (Previously any unescaped `&`
  would cause pandoc not to recognize the string as raw HTML.)
  * Markdown reader:
  + Fix pandoc title blocks with lines ending in 2 spaces.
  + Added `-s` to markdown-reader-more test.
  * HTML reader: fixed bug in `pClose`.  This caused exponential parsing
  behavior in documnets with unclosed tags in `dl`, `dd`, `dt`.
  * MediaWiki reader: Allow spaces before `!` in MediaWiki table header
  * RST reader: Support `:class:` option for code block in RST reader
  * Org reader:
  + Stop padding short table rows.
    Emacs Org-mode doesn't add any padding to table rows.  The first
    row (header or first body row) is used to determine the column count,
    no other magic is performed.
  + Refactor rows-to-table conversion.  This refactors
    the codes conversing a list table lines to an org table ADT.
    The old code was simplified and is now slightly less ugly.
  + Fix handling of empty table cells, rows.
    This fixes Org mode parsing of some corner cases regarding empty cells
    and rows.  Empty cells weren't parsed correctly, e.g. `|||` should be
    two empty cells, but would be parsed as a single cell containing a pipe
    character.  Empty rows where parsed as alignment rows and dropped from
    the output.
  + Fix spacing after LaTeX-style symbols.
    The org-reader was droping space after unescaped LaTeX-style symbol
    commands: `\ForAll \Auml` resulted in `∀Ä` but should give `∀ Ä`
    instead.  This seems to be because the LaTeX-reader treats the
    command-terminating space as part of the command.  Dropping the trailing
    space from the symbol-command fixes this issue.
  + Print empty table rows.  Empty table rows should not
    be dropped from the output, so row-height is always set to be at least 1.
  + Move parser state into separate module.
    The org reader code has become large and confusing.  Extracting smaller
    parts into submodules should help to clean things up.
  + Add support for sub/superscript export options.
    Org-mode allows to specify export settings via `#+OPTIONS` lines.
    Disabling simple sub- and superscripts is one of these export options,
    this options is now supported.
  + Support special strings export option Parsing of special strings
    (like `...` as ellipsis or `--` as en dash) can be toggled using the `-`
    option.
  + Support emphasized text export option.  Parsing of emphasized text can
    be toggled using the `*` option.  This influences parsing of text marked
    as emphasized, strong, strikeout, and underline.  Parsing of inline math,
    code, and verbatim text is not affected by this option.
  + Support smart quotes export option.  Reading of smart quotes can be
    toggled using the `'` option.
  + Parse but ignore export options. All known export options are parsed
    but ignored.
  + Refactor block attribute handling.  A parser state attribute was used
    to keep track of block attributes defined in meta-lines.  Global state
    is undesirable, so block attributes are no longer saved as part of the
    parser state.  Old functions and the respective part of the parser state
    are removed.
  + Use custom `anyLine`.  Additional state changes need to be made after
    a newline is parsed, otherwise markup may not be recognized correctly.
    This fixes a bug where markup after certain block-types would not be
    recognized.
  + Add support for `ATTR_HTML` attributes.
    Arbitrary key-value pairs can be added to some block types using a
    `#+ATTR_HTML` line before the block.  Emacs Org-mode only includes these
    when exporting to HTML, but since we cannot make this distinction here,
    the attributes are always added.  The functionality is now supported
    for figures.
  + Add `:PROPERTIES:` drawer support.
    Headers can have optional `:PROPERTIES:` drawers associated with them.
    These drawers contain key/value pairs like the header's `id`.  The
    reader adds all listed pairs to the header's attributes; `id` and
    `class` attributes are handled specially to match the way `Attr` are
    defined.  This also changes behavior of how drawers of unknown type
    are handled.  Instead of including all unknown drawers, those are not
    read/exported, thereby matching current Emacs behavior.
  + Use `CUSTOM_ID` in properties.  See above on Org writer changes.
  + Respect drawer export setting.  The `d` export option can be used
    to control which drawers are exported and which are discarded.
    Basic support for this option is added here.
  + Ignore leading space in org code blocks.
    Also fix up tab handling for leading whitespace in code blocks.
  + Support new syntax for export blocks.  Org-mode version 9
    uses a new syntax for export blocks.  Instead of `#+BEGIN_<FORMAT>`,
    where `<FORMAT>` is the format of the block's content, the new
    format uses `#+BEGIN_export <FORMAT>` instead.  Both types are
    supported.
  + Refactor `BEGIN...END` block parsing.
  + Fix handling of whitespace in blocks, allowing content to be indented
    less then the block header.
  + Support org-ref style citations.  The *org-ref* package is an
    org-mode extension commonly used to manage citations in org
    documents.  Basic support for the `cite:citeKey` and
    `[[cite:citeKey][prefix text::suffix text]]` syntax is added.
  + Split code into separate modules, making for cleaner code and
    better decoupling.
  * Added `docbook5` template.
  * `--mathjax` improvements:
  + Use new CommonHTML output for MathJax (updated default MathJax URL)
  + Change default mathjax setup to use `TeX-AMS_CHTML` configuration.
    This is designed for cases where the input is always TeX and maximal
    conformity with TeX is desired.  It seems to be smaller and load faster
    than what we used before.  See #2858.
  + Load the full MathJax config to maximize loading speed.
  * Require texmath 0.8.6.2.  Closes several texmath-related bugs
  This fixes behavior of roots, e.g.
  `\sqrt[3]{x}`, and issues with sub/superscript positioning
  and matrix column alignment in docx.
  * README:
  + Clarified documentation of `implicit_header_references`.
  + Improved documentation of `--columns` option.
  * Added appveyor setup, with artefacts.
  * stack.yaml versions: Use proper flags used for texmath, pandoc-citeproc.
  * LaTeX template: support for custom font families.
  Needed for correct polyglossia operation with Cyrillic fonts and perhaps
  can find some other usages.  Example usage in YAML metadata:
    fontfamilies:
  - name: \cyrillicfont
    font: Liberation Serif
  - name: \cyrillicfonttt
    options: Scale=MatchLowercase
    font: Liberation
* Tue Mar 29 2016 mimi.vx@gmail.com
- update to 1.17.0.3
  * LaTeX writer: Fixed position of label in figures. Previously the label wasn't
    in the right place, and `\ref` wouldn't work properly.
  * Added .tei test files to pandoc.cabal so they'll be included in tarball.
* Fri Mar 25 2016 mimi.vx@gmail.com
- update to 1.17.0.2
  * Fixed serious regression in `htmlInBalanced`, which caused
    newlines to be omitted in some raw HTML blocks in Markdown
  * File scope is no longer used when there are no input files (i.e.,
    when input comes from stdin).  Previously file scope was triggered
    when the `json` reader was specified and input came from `stdin`,
    and this caused no output to be produced.
  * Improved documentation of templates
  * Added `--file-scope` option (Jesse Rosenthal).
    By default pandoc operates on multiple files by first concatenating
    them (around extra line breaks) and then processing the joined file. So
    it only parses a multi-file document at the document scope. This has the
    benefit that footnotes and links can be in different files, but for
    some purposes it is useful to parse the individual files first
    and then combine their outputs (e.g. when the files use footnotes
    or links with the same labels).  The `--file-scope` option causes
    pandoc to parse the files first, and then combine the parsed output,
    instead of combining before parsing. `--file-scope` is selected
    automatically for binary input files (which cannot be concatenated)
    and for pandoc json.
  * Add TEI Writer (Chris Forster) and `tei` output format.
  * Added a general `ByteStringReader` with warnings, used by the docx
    reader (API change, Jesse Rosenthal).
  * Add `readDocxWithWarnings` (API change, Jesse Rosenthal).
  * Changed type of `Shared.uniqueIdent`'s argument from `[String]`
    to `Set String.` This avoids performance problems in documents with
    many identically named headers (API change, #2671).
  * Removed `tex_math_single_backslash` from `markdown_github` options
  * Make language extensions as well as full language names
    trigger syntax highlighting.  For example, `py` will now work as
    well as `python` (jgm/highlighting-kate#83).
  * Added `institute` variable to latex, beamer templates (Fraser
    Tweedale, Josef Svenningsson).
  * Docx reader (Jesse Rosenthal):
    + Handle alternate content.  Some word functions (especially graphics)
    give various choices for content so there can be backwards compatibility.
    + Don't turn numbered headers into lists.
    + Docx Reader: Add state to the parser, for warnings
    + Update feature checklist in source code.
    + Get rid of `Modifiable` typeclass.
    + Add tests for adjacent hyperlinks.
    + Add a "Link" modifier to `Reducible`. We want to make sure that
    links have their spaces removed, and are appropriately smushed
    together (#2689).
  * HTML reader:
    + Fixed behavior of base tag (#2777).
    If the base path does not end with slash, the last component
    will be replaced.  E.g. base = `http://example.com/foo`
    combines with `bar.html` to give `http://example.com/bar.html`.
    If the href begins with a slash, the whole path of the base
    is replaced.  E.g. base = `http://example.com/foo/` combines
    with `/bar.html` to give `http://example.com/bar.html`.
    + Rewrote `htmlInBalanced`.  This version avoids an exponential
    performance problem with `<script>` tags, and it should be faster
    in general (#2730).
    + Properly handle an empty cell in a simple table (#2718).
    + Handle multiple `<meta>` tags with same name.  Put them in a list
    in the metadata so they are all preserved, rather than (as before)
    throwing out all but one..
  * Markdown reader:
    + Improved pipe table parsing (#2765).
    + Allow `+` separators in pipe table cells.  We already allowed
    them in the header, but not in the body rows, for some reason.
    This gives compatibility with org-mode tables.
    + Don't cross line boundary parsing pipe table row.
    Previously an Emph element could be parsed across the newline
    at the end of the pipe table row.
    + Use `htmlInBalanced` for `rawVerbatimBlock`, for better
    performance (#2730).
    + Fixed bug with smart quotes around tex math.
  * LaTeX reader:
    + Handle interior `$` characters in math (#2743).  For example,
    `$$\hbox{$i$}$$`.
    + `inlineCommand` now gobbles an empty `{}` after any command (#2687).
    This gives better results when people write e.g. `\TeX{}` in Markdown.
    + Properly handle LaTeX "math" environment as inline math (#2171).
  * Textile reader: Support `>`, `<`, `=`, `<>` text alignment attributes.
  * Org reader (Albert Krewinkel):
    + Prefix even empty figure names with "fig:" (#2643).  The
    convention used by pandoc for figures is to mark them by prefixing
    the name with `fig:`.  The org reader failed to do this if a figure
    had no name.
    + Refactor link-target processing (#2684).
  * ConTeXt writer: Fix whitespace at line beginning in line blocks (#2744).
    Thanks to @c-foster.
  * HTML writer: Don't include alignment attribute for default table columns.
    Previously these were given "left" alignment.  Better to leave off
    alignment attributes altogether (#2694).
  * Markdown writer: Use hyphens for YAML metadata block bottom line, for
    better compatibility with other Markdown flavors (Henrik Tramberend).
  * LaTeX writer:
    + Use image identifier to create a label and hypertarget for
    figures (Mauro Bieg).
    + Avoid double toprule in headerless table with caption (#2742).
    + Clean up options parser (Jesse Rosenthal).
    + Treat `memoir` template with `article` option as article, instead
    of treating all `memoir` templates as books.
    + Allow more flexible table alignment (Henrik Tramberend, #2665).
    New default is not to include `[c]` option (which is the default
    anyway if no positioning is specified).  Now LaTeX emplates can
    control the overall table alignment in a document by setting the
    longtable length variables `LTleft` and `LTright`.  For example,
    `\setlength\LTleft\parindent\setlength\LTright\fill`
    will create left-aligned tables that respect paragraph indentation.
  * Docx writer: Handle image alt text (#2754, Mauro Bieg).
  * Org writer - pass through RawInline with format "org".
  * DokuWiki writer: use `$$` for display math.
  * Custom writer: Pass attributes parameter to CaptionedImage (#2697).
  * Make protocol-relative URIs work again (#2737).
  * make_osx_package.sh:  Use env variable for developer id certs.
  * Raise `tagsoup` lower bound to 0.13.7 to fix entity-related
    problems (#2734).
  * Allow `zip-archive` 0.3.
  * Allow `aeson` 0.11.
* Sun Mar 13 2016 mimi.vx@gmail.com
- remove unused flag
* Sat Jan 23 2016 mimi.vx@gmail.com
- update to 1.16.0.2
- very long changelog again. For details please see changelog file or
    https://hackage.haskell.org/package/pandoc-1.16.0.2/changelog
* Wed Dec 23 2015 mimi.vx@gmail.com
- create placeholder package for pdf support
* Mon Nov 16 2015 mimi.vx@gmail.com
- update to 1.15.2.1
- correct license to GPL-2.0+
- very long changelog again, for details please see changelog file or
  https://hackage.haskell.org/package/pandoc-1.15.2.1/changelog
* Sun Oct 25 2015 mimi.vx@gmail.com
- update to 1.15.1.1
  * `Text.Pandoc.Data`:  store paths in dataFiles using posix separators.
  + add Suggests: texlive-latex-bin-bin
* Sun Oct 18 2015 mimi.vx@gmail.com
- update to 1.15.1
  * `pandocVersion` is now defined in `Text.Pandoc.Shared`
    and reexported from `Text.Pandoc` (Alex Vong).  This allows
    writers to access it.  (Alex Vong) (API change)
  * For `markdown_mmd`, add: `implicit_figures`, `superscripts`,
    `subscripts` (#2401).
  * Added `odt` as input format (MarLinn).  Added new module
    `Text.Pandoc.Reader.ODT` (API change). Fully implemented features:
    Paragraphs, Headers, Basic styling, Unordered lists, Ordered lists,
    External Links, Internal Links, Footnotes, Endnotes, Blockquotes.
    Partly implemented features: Citations, Tables.
  * Markdown Reader:
    + Add basic tests for each header style (Ophir Lifshitz).
    + Add implicit header ref tests for headers with spaces (Ophir Lifshitz).
    + Skip spaces in headers (Ophir Lifshitz).
    + Handle 'id' and 'class' in parsing key/value attributes (#2396).
    `# Header {id="myid" class="foo bar"}`
    is now equivalent to `# Header {#myid .foo .bar}`.
    + Use '=' instead of '#' for atx-style headers in markdown+lhs.
    (Kristof Bastiaensen)
    + Pipe tables: allow indented columns.  Previously the left-hand column
    could not start with 4 or more spaces indent.  This was inconvenient
    for right-aligned left columns.  Note that the first (header column)
    must still have 3 or fewer spaces indentation, or the table will be
    treated as an indented code  block.
    + Fix regression:  allow HTML comments containing `--`.
    Technically this isn't allowed in an HTML comment, but
    we've always allowed it, and so do most other implementations.
    It is handy if e.g. you want to put command line arguments
    in HTML comments.
  * LaTeX reader:
    + Don't eat excess whitespace after macros with only optional
    arguments (#2446).
    + Support longtable (#2411).
    + Implement `\Cite` (#2335).
    + Support abstract environment.  The abstract populates an
    `abstract` metadata field.
    + Properly handle booktabs lines.  Lines aren't part of the
    pandoc table model, so we just ignore them (#2307).
  * HTML reader:
    + Handle type attribute on ol, e.g. `<ol type="i">` (#2313).
    + Updated for new automatic header attributes.
    + Add auto identifiers if not present on headers.  This makes
    TOC linking work properly.
    + Detect `font-variant` with `pickStyleAttrProps` (Ophir Lifshitz).
    + Test `<ol>` type, class, and inline list-style(-type) CSS
    (Ophir Lifshitz).
    + Better handling of "section" elements (#2438).  Previously
    `<section>` tags were just parsed as raw HTML blocks.  With
    this change, section elements are parsed as Div elements with
    the class "section".
  * MediaWiki reader:  handle unquoted table attributes (#2355).
  * DocBook reader:
    + Added proper support for DocBook `xref` elements (Frerich Raabe).
    Added `dbContent` field to reader state, so we can lookup
    cross refs.
    + Handle `informalexample` (#2319).
  * Docx Reader:
    + Create special punctuation test (Ophir Lifshitz).
    + Parse soft, no-break hyphen elements (Ophir Lifshitz).
    + Updated headers test (Ophir Lifshitz). Replaced `styles.xml`
    in `headers.docx` with pandoc's current `styles.xml`, which
    contains styles for Heading 1 through 6. Added Heading 4
    through 7 to the test document. Note that Heading 7 is not
    parsed as a Heading because there is no Heading 7 style.
  * RST reader:  better handling of indirect roles.
    Previously the parser failed on this kind of case
    .. role:: indirect(code)
    .. role:: py(indirect)
    :language: python
    :py:`hi`
    Now it correctly recognizes `:py:` as a code role.
  * Org reader:
    + Add auto identifiers if not present on headers
    (#2354, Juliusz Gonera).
    + Allow verse blocks to contain empty lines (#2402,
    Albert Krewinkel).
  * EPUB reader:  stop mangling external URLs (#2284).
  * RST writer:
    + Don't insert `\ ` when complex expression in matched pairs.
    E.g. `` [:sup:`3`] `` is okay; you don't need `` [:sup:`3`\ ] ``.
    + Ensure that `\ ` is inserted when needed before Cite and Span
    elements that begin with a "complex" element (jgm/pandoc-citeproc#157).
    + Normalize headers only in "standalone" mode (#2394).
  * Haddock writer: escape `*` and `^` (G. Bataille).
  * Markdown writer:
    + In TOC, add links to headers (#829).
    + Use unicode super/subscripts for digits in plain output
    (when the `superscripts` and `subscripts` extensions are
    not enabled).
  * Docx writer:
    + Moved invalid character stripping to `formattedString`.
    This avoids an inefficient generic traversal (#2356).
    + Use user data directory for `reference.docx` archive.
    This allows the test suite to work without installing pandoc first.
    It also brings the docx writer in line with the odt writer.
    + Tests:  docx writer tests now use `../data` for data directory.
    This allows tests to be run without installing first.
    + Tests: Use real jpg (not empty) for docx tests to avoid warning.
  * LaTeX writer:
    + Fixed detection of 'chapters' from template.
    If a documentclass isn't specified in metadata, but the
    template has a hardwired bookish documentclass, act as if
    `--chapters` was used.  This was the default in earlier
    versions, but it has been broken for a little while.
    + Correctly recognize book documentclass in metadata (#2395).
    + Set language-related variables automatically, depending
    on the value of the `lang` field, which is now always
    assumed to be in BCP47 format (mb21, #1614, #2437).
    + Add `\protect` to `\hyperdef` in inline context.  This way we
    don't get an error when this is used as a moveable argument (#2136).
    + Support all frame attributes in Beamer.
    + Percent-encode more special characters in URLs (#1640, #2377).
    The special characters are '<','>','|','"','{','}','[',']','^', '`'.
  * HTML writer:
    + Update KaTeX JS and CSS versions (Emily Eisenberg).
    + For dzslides, add `role="note"` for speaker notes (#1693).
    + Percent-encode more special characters in URLs (#1640, #2377).
    The special characters are '<','>','|','"','{','}','[',']','^', '`'.
    + Render Div with class `section` as `<section>` in HTML5.
  * EPUB writer:
    + In TOC, replace literal "<br/>" with space (#2105).
    + With `--webtex`, include image file rather than `data:` URI (#2363).
  * Native writer: format Div properly, with blocks separated.
  * Support bidirectional text output with XeLaTeX, ConTeXt and HTML
  * Reference Docx:
    + Add missing Header 6 style (steel blue) (Ophir Lifshitz).
    + Correct `outlineLvl` for Header styles (Ophir Lifshitz).
  * Templates
    + Beamer:  Add `innertheme`, `outertheme` variables
    (Guilhem Bonnefille, #121). Add space after colon in figure caption.
    Integrate recent font and language updates from LaTeX template;
    allow use of `mainfont` variable for changing the slide text
    in XeTeX and LuaTeX (Andrew Dunning, #131).
    + LaTeX:  Add `mainfontoptions`, `sansfontoptions`,
    `monofontoptions`, `mathfontoptions`, `fontfamilyoptions`
    (Andrew Dunning, #122).  Support handling of bidirectional
    text (mb21, #120). Improve reliability of superscripts/subscripts
    under XeTeX and prevent letters and numbers from appearing on a
    different baseline by removing use of the `realscripts` package
    (via `xltxtra`).  To restore use of OpenType characters for these
    features under XeTeX or LuaTeX, add `\usepackage{realscripts}` to
    `header-includes` (Andrew Dunning, #130).  Remove redundant
    reference to `xunicode` (Andrew Dunning, #130).  Add `fontenc`,
    `indent`, `subparagraph` variables (Andrew Dunning).
    Allow use of `hidelinks` variable for `hyperref` package (Hugo Roy,
    [#113]).  Prevent package clash with `tufte-latex` and other classes that
    include `hyperref` or `color` (Xavier Olive, #115).
    + ConTeXt:  Support handling of bidirectional text (mb21, #120).
    + LaTeX and ConTeXt: Use more specific language variables.
    Instead of directly using `lang`, we now use `babel-lang` and
    `polyglossia-lang` and `context-lang`.  These variables are set by
    the writers to the necessary values, based on the `lang` variable
    (which now always takes a value in BCP47 format). (mb21, #114, #129).
    + HTML:  Support handling of bidirectional text (mb21, #120).
    Move HTML5 shiv after CSS and fix URL (Andrew Dunning).
    Add dir attribute in html5 (Andrew Dunning).
    + reveal.js: Add `controls`, `progress` variables (Grégoire Pineau, #127).
    Add `width`, `height` variables (Anrew Dunning).  Update template
    from 3.1 source (Andrew Dunning).  All configuration options are now
    available as variables, but are only be included if set (reveal.js
    uses defaults otherwise).
    + man: Added comment stating that the page is autogenerated by pandoc,
    giving version.  Added `adjusting` and `hyphenate` variables
    (Alex Vong, #123).
  * epub.css: added selectors for nested emphasis (Pablo Rodriguez).
  * MediaBag:  ensure that `/` is always used as path separator.
  * `sample.lua`: define `CaptionedImage`, add newline at end (#2393).
  * Added `--bash-completion` option.  This generates a bash completion
    script.  To use: `eval "$(pandoc --bash-completion)"`.
  * Text.Pandoc.Error: Define Typeable and Exception instances
    for PandocError (#2386).
  * Text.Pandoc.Parsing: `toKey`: strip off outer brackets.
    This makes keys with extra space at the beginning and end
    work:  e.g.
    [foo]: bar
    [ foo ]
    will now be a link to bar (it wasn't before).
  * Text.Pandoc: disable `auto_identifiers` for epub.
    The epub writer inserts its own auto identifiers;
    this is more complex due to splitting into "chapter" files.
  * Renamed Text.Pandoc.Compat.Locale -> Text.Pandoc.Compat.Time.
    It now reexports Data.Time.
  * Use custom Prelude to avoid compiler warnings.
    + The (non-exported) prelude is in prelude/Prelude.hs.
    + It exports Monoid and Applicative, like base 4.8 prelude,
    but works with older base versions.
    + It exports (<>) for mappend.
    + It hides 'catch' on older base versions.
  * Added a `stack.ymal` and stack install instructions to INSTALL.
  * Clarified what is "out of scope" in README and CONTRIBUTING.md.
  * Added note to CONTRIBUTING.md about ghc versions and travis.
  * Clarify docs on block quotes.  The space after `>` is optional (#2346).
  * Removed obsolete reference to default.csl (#2372).
  * List all styles in manual for `--reference-docx` (Chris Black)
  * Don't capitalize header links in man page.
  * Added section on repl to CONTRIBUTING.md.
  * README:  Added space after backslash in image example (#2329).
  * Document details of citation locator terms (Nick Bart).
  * Fixed some internal links in README (#2309).
  * Improve CSL documentation, variables documentations,
    links, and cross-references in README. (Andrew Dunning)
  * Fix build failure with `--flags=-https` (Sergei Trofimovich).
  * Use `newManager` instead of `withManager` in recent `http-client`.
    This avoids a deprecation warning.
  * Allow building with latest versions of http-types,
    HUnit, criterion, syb, aeson.
  * Setup.hs: rewrite so as not to use process, directory, filepath.
    Using anything outside base is dangerous, since older
    versions of ghc may link against two different versions.
* Tue Jul 28 2015 mimi.vx@gmail.com
- update to 1.15.0.6
- removed man.patch , pandoc.1.gz and pandoc_markdown.5.gz
  * `--self-contained`:  Fixed overaggressive CSS minimization (#2301, 2286).
    Previously `--self-contained` wiped out all spaces in CSS,
    including semantically significant spaces.  This was a regression
    from 1.14.x.
  * Markdown reader: don't allow bare URI links or autolinks in link
    label (#2300).  Added test cases.
  * `Text.Pandoc.Parsing`, `uri`: Improved bare autolink detection (#2299).
    Previously we disallowed `-` at the end of an autolink,
    and disallowed the combination `=-`.  This commit liberalizes the
    rules for allowing punctuation in a bare URI, and adds test cases.
    One potential drawback is that you can no longer put a bare
    URI in em dashes like this:
    `this uri---http://example.com---is an example.`
    But in this respect we now match github's treatment of bare URIs.
  * HTML writer:  support speaker notes in dzslides.
    With this change `<div class="notes">` and also `<div class="notes"
    role="note">` will be output if `-t dzslides` is used. So we can
    have speaker notes in dzslides too.  Thanks to maybegeek.
  * Updated dzslides template.
  * Improved documentation of options to print system default files (#2298).
    `--print-default-data-file` and `--print-default-template`.
  * DokuWiki writer: use `$..$` for Math instead of `<math>..</math>`
    (Tiziano Müller).  MathJax seems currently to be the only maintained
    math rendering extension for DokuWiki.
  * `Text.Pandoc.Shared`: Changed `hierarchicalize` so it treats references
    div as top-level header (#2294).  This fixes a bug with `--section-divs`,
    where the final references section added by pandoc-citeproc, enclosed in
    its own div, got nested in the div for the section previous to it.
  * Allow vector 0.11.
  * Require cmark > 0.4.
  * HTML writer: Fixed email javascript obfuscation with `mailto:`
    URLs (#2280).  This fixes a potential security issue.  Because
    single quotes weren't being escaped in the link portion, a
    specially crafted email address could allow javascript code injection.
  * Markdown/HTML readers:  Avoid parsing partial URLs like
    `<www.pandoc.org/blah#foo>` as HTML tags (#2277).
  * RST reader:  allow inline formatting in definition list field
    names (Lars-Dominik Braun).
  * PDF:  Make sure `--latex-engine-opt` goes before the filename
    on the command line.  LaTeX needs the argument to come after
    the options (#1779).
  * CommonMark writer: fixed tags used for super/subscript.
  * ConTeXt template:  activate hanging indent for definition lists
    (mb21).
  * Make cabal require `hsb2hs` >= 0.3.1 if `embed_data_files` specified.
    This is done by adding `hookedPrograms` in `Setup.hs`, which allows us
    to include `hsb2hs` in Build-Tools in cabal.
    + Admin privileges are no longer required for a per-user install
  * Travis:  unpack sdist for build to catch packaging bugs.
  * Improved documentation on where user templates go (#2272).
  * Added pandoc.1 man page to the repository.  It is no longer
    built as part of the cabal build process. (This proved too
    fragile.)  pandoc.1 can be regenerated (`make man/pandoc.1`)
    when `README` is changed.
  * Copying of the man page now respects `--destdir` (#2262).
  * Improved error messages for filters.  User is now informed if
    the filter requires an interpreter that isn't found in the path,
    or if the filter returns an error status.
  * Ensure target directory is created when installing man page.
  * Added files needed for building man page to Extra-Source-Files.
  * Man page is now built and installed as part of the cabal build
    process. Removed Makefile target for man page.
  * Man page changes:
    + Removed `--man1`, `--man5` options (breaking change).
    + Removed `Text.Pandoc.ManPages` module (breaking API change).
    + Makefile target for `man/man1/pandoc.1`.  This uses pandoc to
    create the man page from README using a custom template and filters.
    + Added `man/` directory with template and filters needed to build
    man page.
    + We no longer have two man pages: `pandoc.1` and `pandoc_markdown.5`.
    Now there is just pandoc.1, which has all the content from README.
    This change was needed because of the extensive cross-references
    between parts of the README.
    + Removed old `data/pandoc.1.template` and
    `data/pandoc_markdown.5.template`.
  * OpenDocument writer: Do not add a carriage return after a hard
    line break (Michael Chladek).
  * ConTeXt writer:
    + use `\goto` for internal links.
    + Added a `%%` at end for `\reference` to avoid spurious space.
  * Ignore sandbox on 'make quick'
  * Added new unexported module:  `Text.Pandoc.ManPages`.
  * `README` now acts like a data file (even though it isn't in
    `data/`).  So, for example, `pandoc --print-default-data-file README`
    will produce the README.)  This change was required for the `--man1`
    and `--man5` options, since the man pages are produced from the
    README, but it may be useful for other purposes as well.
  * Allow `reference.docx` and `reference.odt` to be used with
    `--print-default-data-file` and to shadow defaults if placed in
    the user data directory.  Note that as of 1.14, we no longer
    include these files as data files; instead, we include their
    components.  This change causes pandoc to behave as if it has
    these data files; they are constructed on demand when needed
    using `getDefaultReferenceDocx` and `getDefaultReferenceODT`.
  * Fixed regression in CSS parsing with `--self-contained` (#2224).
    Pandoc 1.14.0.x used css-text to parse the CSS, but its parser
    silently drops big sections of CSS.  This commit replaces the
    use of css-text with a small but principled CSS preprocessor,
    which removes whitespace and comments and replaces `url()` with
    base 64 data when possible.
  * Use `https://` instead of `//` for MathJax and KaTeX CDN URLs (#1920).
    This will allow math to work when pages are being viewed locally.
  * `Text.Pandoc.Options`:  Export `plainExtensions`.
    These are the extensions used in `plain` output.
  * LaTeX reader: Don't parse `_` and `^` as sub/superscript outside of
    math mode; treat them as regular inline text.  Normally these will
    cause an error in LaTeX, but there are contexts (e.g. `alltt`
    environments) where they are allowed.
  * HTML reader:  allow `<body>` to close `<head>`.
  * DocBook reader: support `mediaobject`s and `figures` (#2184, mb21).
  * RST reader: Fix reference names with special characters
    (Lars-Dominik Braun).
  * Textile writer:  escape `+` and `-` as entities (#2225).
  * DokuWiki writer: Use proper `<code>` tags for code blocks (#2213).
  * Plain writer:  don't use symbols for super/subscript (#2237).
    Simplified code by using `plainExtensions`.
  * InDesign writer: Properly escape URLs containing more than one
    colon character (gohai).
  * Docx writer: Make sure we use dist version of `reference.docx`
    (and not the user's version) for certain settings.  Taking some
    settings values from a user-supplied reference.docx can lead to
    corruption.  This fixes a regression from the last release (#2249).
  * `Text.Pandoc.Shared`: exports `getDefaultReferenceDocx` and
    `getDefaultReferenceODT` (API change).  These functions have been
    removed from the Docx and ODT writers.
  * LaTeX template (Xavier Olive):
    + Added `CJKmainfont` and `CJKoptions` variables.
    + Allow dvipsnames (e.g. `MidnightBlue`) for colors (Xavier Olive).
  * Epub templates:  use `author.role`, not `author.type`.
  * Bump cmark version to >= 0.3.4.
  * Improved Windows installer (#2205, thanks to nkalvi).
    Users can now select a per-user or systemwide install, and can set
    the installation path.  At the end of installation, the install location
    is given.  The install location is also now given in the list of
    installed programs in Control Panel.  Cleaner WiX syntax is used for
    setting the path.
  * Added `download_stats` target to Makefile.
* Thu Jun  4 2015 mimi.vx@gmail.com
- update to 1.14.0.4
  * Added missing commonmark template.
* Tue Jun  2 2015 mimi.vx@gmail.com
- update to 1.14.0.3
  * Allow compilation with syb 0.5.*.
  * Custom writer: fixed some compiler warnings for ghc < 7.10.
* Tue Jun  2 2015 mimi.vx@gmail.com
- reworked man patch
* Sun May 31 2015 mimi.vx@gmail.com
- update to 1.14.0.2
- man.patch to remove generating of man pages
  * for changes please see upstream 'changelog' file
* Thu May 14 2015 mimi.vx@gmail.com
- disable old-locale support
* Sun Apr 26 2015 mimi.vx@gmail.com
- correct ghc-http-client-tls dep
* Fri Apr 24 2015 mimi.vx@gmail.com
- update to 1.13.2.1
  pandoc (1.13.2)
  ===============
  * TWiki Reader: add new new twiki reader (API chaneg, Alexander Sulfrian).
  * Markdown reader:
    + Better handling of paragraph in div (#1591).
    Previously text that ended a div would be parsed as Plain
    unless there was a blank line before the closing div tag.
    + Don't treat a citation as a reference link label (#1763).
    + Fix autolinks with following punctuation (#1811).
    The price of this is that autolinked bare URIs can no longer
    contain `>` characters, but this is not a big issue.
    + Fix `Ext_lists_without_preceding_blankline` bug (#1636, Artyom).
    + Allow `startnum` to work without `fancy_lists`. Formerly
    `pandoc -f markdown-fancy_lists+startnum` did not work properly.
  * RST reader (all Daniel Bergey):
    + Parse quoted literal blocks (#65).  RST quoted literal blocks are
    the same as indented literal blocks (which pandoc already supports)
    except that the quote character is preserved in each line.
    + Parse RST class directives. The class directive accepts one or more
    class names, and creates a Div value with those classes.  If the
    directive has an indented body, the body is parsed as the children of
    the Div.  If not, the first block folowing the directive is made a
    child of the Div. This differs from the behavior of rst2xml, which
    does not create a Div element.  Instead, the specified classes are
    applied to each child of the directive.  However, most Pandoc Block
    constructors to not take an Attr argument, so we can't duplicate this
    behavior.
    + Warn about skipped directives.
    + Literal role now produces Code. Code role should have "code" class.
    + Improved support for custom roles
  - Added `sourceCode` to classes for `:code:` role, and anything
    inheriting from it.
  - Add the name of the custom role to classes if the Inline
    constructor supports Attr.
  - If the custom role directive does not specify a parent role,
    inherit from the `:span:` role.
    This differs somewhat from the `rst2xml.py` behavior.  If a custom
    role inherits from another custom role, Pandoc will attach both
    roles' names as classes.  `rst2xml.py` will only use the class of
    the directly invoked role (though in the case of inheriting from a
    `:code:` role with a `:language:` defined, it will also provide the
    inherited language as a class).
    + Warn about ignored fields in role directives.
  * LaTeX reader:
    + Parse label after caption into a span instead of
    inserting an additional paragraph of bracketed text (#1747).
    + Parse math environments as inline when possible (#1821).
    + Better handling of `\noindent` and `\greektext` (#1783).
    + Handle `\texorpdfstring` more gracefully.
    + Handle `\cref` and `\sep` (Wikiwide).
    + Support `\smartcite` and `\Smartcite` from biblatex.
  * HTML reader:
    + Retain display type of MathML output (#1719, Matthew Pickering).
    + Recognise `<br>` tags inside `<pre>` blocks (#1620, Matthew Pickering).
    + Make `embed` tag either block or inline (#1756).
  * DocBook reader:
    + Handle `keycombo`, `keycap` (#1815).
    + Get string content in inner tags for literal elements (#1816).
    + Handle `menuchoice` elements better, with a `>` between (#1817).
    + Include `id` on section headers (#1818).
    + Document/test "type" as implemented (Brian O'Sullivan).
    + Add support for calloutlist and callout (Brian O'Sullivan).
    We treat a calloutlist as a bulleted list. This works well in practice.
    + Add support for `classname` (Bryan O'Sullivan).
  * Docx reader:
    + Fix window path for image lookup (Jesse Rosenthal).
    Don't use os-sensitive "combine", since we always want the paths in our
    zip-archive to use forward-slashes.
    + Single-item headers in ordered lists are headers (Jesse Rosenthal).
    When users number their headers, Word understands that as a single item
    enumerated list. We make the assumption that such a list is, in fact,
    a header.
    + Rewrite rewriteLink to work with new headers (Jesse Rosenthal).
    There could be new top-level headers after making lists, so we have to
    rewrite links after that.
    + Use polyglot header list (Jesse Rosenthal).
    We're just keeping a list of header formats that different languages
    use as their default styles. At the moment, we have English, German,
    Danish, and French. We can continue to add to this.
    This is simpler than parsing the styles file, and perhaps less
    error-prone, since there seems to be some variations, even within a
    language, of how a style file will define headers.
    + Remove header class properly in other langs (Jesse Rosenthal).
    When we encounter one of the polyglot header styles, we want to remove
    that from the par styles after we convert to a header. To do that, we
    have to keep track of the style name, and remove it appropriately.
    + Account for external link URLs with anchors. Previously, if a URL
    had an anchor, the reader would incorrectly identify it as an
    internal link and return only the anchor as URL. (Caleb McDaniel)
    + Fix for Issue #1692 (i18n styles) (Nikolay Yakimov).
  * Org reader:
    + Added state changing blanklines (Jesse Rosenthal).
    This allows us to emphasize at the beginning of a new paragraph (or, in
    general, after blank lines).
    + Fixed bug with bulleted lists:
  - a
  - b
  * c
    was being parsed as a list, even though an unindented `*`
    should make a heading.  See
    <http://orgmode.org/manual/Plain-lists.html#fn-1>.
    + Org reader: absolute, relative paths in link (#1741, Albert
    Krewinkel). The org reader was too restrictive when parsing links;
    some relative links and links to files given as absolute paths
    were not recognized correctly.
    + Org reader:  allow empty links (jgm/gitit#471, Albert Krewinkel).
    This is important for use in gitit, which uses empty links
    for wikilinks.
    + Respect indent when parsing Org bullet lists (#1650, Timothy
    Humphries).  Fixes issue with top-level bullet list parsing.
    + Fix indent issue for definition lists (Timothy Humphries,
    see #1650, #1698, #1680).
    + Parse multi-inline terms correctly in definition list (#1649,
    Matthew Pickering).
    + Fix rules for emphasis recognition (Albert Krewinkel).
    Things like `/hello,/` or `/hi'/` were falsy recognized as emphasised
    strings.  This is wrong, as `,` and `'` are forbidden border chars and
    may not occur on the inner border of emphasized text.
    + Drop COMMENT document trees (Albert Krewinkel).
    Document trees under a header starting with the word `COMMENT` are
    comment trees and should not be exported.  Those trees are dropped
    silently (#1678).
    + Properly handle links to `file:target` (Albert Krewinkel).
    Org links like `[[file:target][title]]` were not handled correctly,
    parsing the link target verbatim.  The org reader is changed such that
    the leading `file:` is dropped from the link target (see #756, #1812).
    + Parse LaTeX-style MathML entities (#1657, Albert Krewinkel).
    Org supports special symbols which can be included using LaTeX syntax,
    but are actually MathML entities.  Examples for this are
    `\nbsp` (non-breaking space), `\Aacute` (the letter A with accent acute)
    or `\copy` (the copyright sign ©)
  * EPUB reader:
    + URI handling improvements. Now we outsource most of the work to
    `fetchItem'`. Also, do not include queries in file extensions (#1671).
  * LaTeX writer:
    + Use `\texorpdfstring` for section captions when needed (Vaclav Zeman).
    + Handle consecutive linebreaks (#1733).
    + Protect graphics in headers (Jesse Rosenthal).
    Graphics in `\section`/`\subsection` etc titles need to be `\protect`ed.
    + Put `~` before header in list item text (Jesse Rosenthal).
    Because of the built-in line skip, LaTeX can't handle a section header
    as the first element in a list item.
    + Avoid using reserved characters as `\lstinline` delimiters (#1595).
    + Better handling of display math in simple tables (#1754).
    We convert display math to inline math in simple tables,
    since LaTeX can't deal with display math in simple tables.
    + Escape spaces in code (#1694, Bjorn Buckwalter).
  * MediaWiki writer:
    + Fixed links with URL = text. Previously these were rendered as bare
    words, even if the URL was not an absolute URL (#1825).
  * ICML writer:
    + Don't force all citations into footnotes.
  * RTF writer:
    + Add blankline at end of output (#1732, Matthew Pickering).
  * RST writer:
    + Ensure blank line after figure.
    + Avoid exces whitespace after last list item (#1777).
    + Wrap line blocks with spaces before continuations (#1656).
    + Fixed double-rendering of footnotes in RST tables (#1769).
  * DokuWiki writer:
    + Better handling of block quotes. This change ensures that
    multiple paragraph blockquotes are rendered using native `>`
    rather than as HTML (#1738).
    + Fix external images (#1739). Preface relative links with ":",
    absolute URIs without. (Timothy Humphries)
  * HTML writer:
    + Use protocol-relative URL for mathjax.
    + Put newline btw img and caption paragraph.
    + MathML now outputted with tex annotation (#1635, Matthew Pickering).
    + Add support for KaTeX HTML math (#1626, Matthew Pickering).
    This adds `KaTeX` to `HTMLMathMethod` (API change).
    + Don't double render when `email-obfuscation=none` (#1625, Matthew
    Pickering).
    + Make header attributes work outside top level (#1711).
    Previously they only appeared on top level header elements.
    Now they work e.g. in blockquotes.
  * ODT writer:
    + Correctly handle images without extensions (#1729).
    + Strip querystring in ODT write (#1682, Todd Sifleet).
  * FB2 writer:
    + Add newline to output.
  * EPUB writer:
    + Don't add `sourceURL` to absolute URIs (#1669).
    + Don't use unsupported `opf:title-type` for epub2.
    + Include "landmarks" section in nav document for epub3 (#1757).
    + Removed playOrder from navpoint elements in ncx file (#1760).
    These aren't required, and they make manual modification of epubs
    difficult.
    + Extract title even from structured title.
    + Don't include nav node in spine unless `--toc` was requested.
    Previously we included it in the spine with `linear="no"`, leading
    to odd results in some readers (#1593).
    + Fixed absolute URI detection (#1672).
    + Correctly resolve relative URIs (#1671).
    + Use regular page template for `nav.xhtml`, including doctype (#1759).
  * Docx writer:
    + Put docx table captions above tables (#1641, Nikolay Yakimov).
    + Get the page width from the reference docx file, and use
    it to scale images that are too large to fit (Grégory Bataille).
    + Partial fix for #1607 (Nikolay Yakimov). International heading styles
    are inferred based on `<w:name val="heading #">` fallback, if there
    are no en-US "Heading#" styles
    + Look in user data dir for archive `reference.docx`.
    + Renumber header and footer relationships to avoid collisions (Jesse
    Rosenthal). We previously took the old relationship names of the
    headers and footer in secptr. That led to collisions. We now make
    a map of availabl names in the relationships file, and then rename
    in secptr.
  * ConTeXt writer:
    + Add function toLabel (Mark Szepieniec).
    This function can be used to sanitize reference labels so that
    they do not contain any of the illegal characters \#[]",{}%%()|= .
    Currently only Links have their labels sanitized, because they
    are the only Elements that use passed labels.
  * `Text.Pandoc.Shared`:
    + Moved import of `toChunks` outside of CPP conditional (#1590).
    + Fix `inDirectory` to reset to the original directory in case
    an exception occurs (Freiric Barral).
  * Templates:
    + LaTeX template: load polyglossia before bibtex (jgm/pandoc-templates#70).
    Thanks to bluebirch.
    + LaTeX template: Added `\VerbatimFootnotes` if there is verbatim in notes
    (#1616).
    + LaTeX template:  Add shorthands=off to babel options (#1648).
    + EPUB, EPUB3 templates: Added `id="cover"` to body of cover page.
    This aids styling, making it possible for example to set 0 margins
    on the title page (#1758).
    + EPUB, EPUB3 templates:  Handle structured metadata on titlepage.
    Previously we just expected 'title', 'subtitle', 'author', 'date'.
    Now we still support those, but also support the format recommended
    for epub metadata in the pandoc README:
  - --
    title:
  - type: main
    text: My Book
  - type: subtitle
    text: An investigation of metadata
    creator:
  - role: author
    text: John Smith
  - role: editor
    text: Sarah Jones
    identifier:
  - scheme: DOI
    text: doi:10.234234.234/33
    publisher:  My Press
    rights:  (c) 2007 John Smith, CC BY-NC
    ...
  * `Text.Pandoc.Templates.getDefaultTemplate`:
    don't fail when called with "fb2" (#1660).
  * `Text.Pandoc.Parsing`:
    + Fixed `inlineMath` so it handles `\text{..}` containing `$`.
    For example: `$x = \text{the $n$th root of $y$}` (#1677).
    + Change `parseFromString` to fail if not all input is consumed.
    (Matthew Pickering)
    + Moved `addWarning` from Markdown reader to `Parsing`, so it can be
    used by more readers (API change, Daniel Bergey).
  * `Text.Pandoc.Pretty`:
    +  Improve performance of `realLength` (Matthew Pickering).
    +  Make CR + BLANKLINE = BLANKLINE. This fixes an extra blank line we
    were getting at the end of markdown fragments (as well as rst, org,
    etc.) (#1705).
  * `Text.Pandoc.MIME`:
    + Add mime type for WebVTT (Jason Ronallo).
    + Changed mime type for `otf` to `application/vnd.ms-opentype` (#1761).
    This is needed for epub3 validation.
  * `Text.Pandoc.MediaBag`:
    + Fix Windows specific path problems (#1597).
  * `Text.Pandoc.Shared`:
    + Make `collapseFilePath` OS-agnostic (Matthew Pickering).
  * Link the test suite using `-threaded`.
    This allows the test suite to be run using `+RTS -N`.
  * Added `network` dependency under `network-uri` flag in test section.
  * Give better error messages when someone tries to convert from
    pdf, doc, odt (#1683).
  * Added `track` to list of tags treated by `--self-contained` (#1664).
  pandoc (1.13.1)
  ===============
  * Fixed `--self-contained` with Windows paths (#1558).
    Previously `C:\foo.js` was being wrongly interpreted as a URI.
  * HTML reader:  improved handling of tags that can be block or inline.
    Previously a section like this would be enclosed in a paragraph,
    with RawInline for the video tags (since video is a tag that can
    be either block or inline):
    <video controls="controls">
    <source src="../videos/test.mp4" type="video/mp4" />
    <source src="../videos/test.webm" type="video/webm" />
    <p>
    The videos can not be played back on your system.<br/>
    Try viewing on Youtube (requires Internet connection):
    <a href="http://youtu.be/etE5urBps_w">Relative Velocity on
    Youtube</a>.
    </p>
    </video>
    This change will cause the video and source tags to be parsed
    as RawBlock instead, giving better output.
    The general change is this:  when we're parsing a "plain" sequence
    of inlines, we don't parse anything that COULD be a block-level tag.
  * Docx reader:
    + Be sensitive to user styles.  Note that "Hyperlink" is
    "blacklisted," as we don't want the default underline styling to be
    inherited by all links by default (Jesse Rosenthal).
    + Read single paragraph in table cell as `Plain` (Jesse Rosenthal).
    This makes to docx reader's native output fit with the way the markdown
    reader understands its markdown output.
  * Textile writer:  Extended the range of cases where native textile
    tables will be used (as opposed to raw HTML):  we now handle any
    alignment type, but only for simple tables with no captions.
  * Txt2Tags reader:
    + Header is now parsed only if standalone flag is set (Matthew Pickering).
    + The header is now parsed as meta information. The first line is the
    `title`, the second is the `author` and third line is the `date`
    (Matthew Pickering).
    + Corrected formatting of `%%%%mtime` macro (Matthew Pickering).
    + Fixed crash when reading from stdin.
  * EPUB writer:  Don't use page-progression-direction in EPUB2, which
    doesn't support it.  Also, if page-progression-direction not specified
    in metadata, don't include the attribute even in EPUB3; not including it
    is the same as including it with the value "default", as we did before.
    (#1550)
  * Org writer: Accept example lines with indentation at the beginning
    (Calvin Beck).
  * DokuWiki writer:
    + Refactor to use Reader monad (Matthew Pickering).
    + Avoid using raw HTML in table cells; instead, use `\\`
    instead of newlines (Jesse Rosenthal).
    + Properly handle HTML table cell alignments, and use spacing
    to make the tables look prettier (#1566).
  * Docx writer:
    + Bibliography entries get `Bibliography` style (#1559).
    + Implement change tracking (Jesse Rosenthal).
  * LaTeX writer:
    + Fixed a bug that caused a table caption to repeat across all pages
    (Jose Luis Duran).
    + Improved vertical spacing in tables and made it customizable using
    standard lengths set by booktab.  See
    <https://groups.google.com/forum/#!msg/pandoc-discuss/qMu6_5lYy0o/ZAU7lzAIKw0J>
    (Jose Luis Duran).
    + Added `\strut` to fix spacing in multiline tables (Jose Luis Duran).
    + Use `\tabularnewline` instead of `\\` in table cells (Jose Luis Duran).
    + Made horizontal rules more flexible (Jose Luis Duran).
  * Text.Pandoc.MIME:
    + Added `MimeType` (type synonym for `String`) and `getMimeTypeDef`.
    Code cleanups (Artyom Kazak).
  * Templates:
    + LaTeX template: disable microtype protrusion for typewriter font (#1549,
    thanks lemzwerg).
  * Improved OSX build procedure.
  * Added `network-uri` flag, to deal with split of `network-uri` from
    `network`.
  * Fix build dependencies for the `trypandoc` flag, so that they are
    ignored if `trypandoc` flag is set to False (Gabor Pali).
  * Updated README to remove outdated claim that `--self-contained`
    looks in the user data directory for missing files.
  pandoc (1.13.0.1)
  =================
  * Docx writer:
    + Fixed regression which bungled list numbering (#1544), causing
    all lists to appear as basic ordered lists.
    + Include row width in table rows (Christoffer Ackelman, Viktor Kronvall).
    Added a property to all table rows where the sum of column widths
    is specified in pct (fraction of 5000).  This helps persuade Word
    to lay out the table with the widths we specify.
  * Fixed a bug in Windows 8 which caused pandoc not to find the
    `pandoc-citeproc` filter (#1542).
  * Docx reader: miscellaneous under-the-hood improvements (Jesse Rosenthal).
    Most significantly, the reader now uses Builder, leading to some
    performance improvements.
  * HTML reader:  Parse appropriately styled span as SmallCaps.
  * Markdown writer: don't escape `$`, `^`, `~` when `tex_math_dollars`,
    `superscript`, and `subscript` extensions, respectively, are
    deactivated (#1127).
  * Added `trypandoc` flag to build CGI executable used in the online
    demo.
  * Makefile:  Added 'quick', 'osxpkg' targets.
  * Updated README in templates to indicate templates license.
    The templates are dual-licensed, BSD3 and GPL2+.
  pandoc (1.13)
  =============
  * Added `docx` as an input format (Jesse Rosenthal).  The docx
    reader includes conversion of native Word equations to pandoc
    LaTeX `Math` elements.  Metadata is taken from paragraphs at the
    beginning of the document with styles `Author`, `Title`, `Subtitle`,
    `Date`, and `Abstract`.
  * Added `epub` as an input format (Matthew Pickering).  The epub
    reader includes conversion of MathML to pandoc LaTeX `Math`
    elements.
  * Added `t2t` (Txt2Tags) as an input format (Matthew Pickering).
    Txt2tags is a lightweight markup format described at
    <http://txt2tags.org/>.
  * Added `dokuwiki` as an output format (Clare Macrae).
  * Added `haddock` as an output format.
  * Added `--extract-media` option to extract media contained in a zip
    container (docx or epub) while adjusting image paths to point to the
    extracted images.
  * Added a new markdown extension, `compact_definition_lists`, that
    restores the syntax for definition lists of pandoc 1.12.x, allowing
    tight definition lists with no blank space between items, and
    disallowing lazy wrapping.  (See below under behavior changes.)
  * Added an extension `epub_html_exts` for parsing HTML in EPUBs.
  * Added extensions `native_spans` and `native_divs` to activate
    parsing of material in HTML span or div tags as Pandoc Span
    inlines or Div blocks.
  * `--trace` now works with the Markdown, HTML, Haddock, EPUB,
    Textile, and MediaWiki readers.  This is an option intended
    for debugging parsing problems; ordinary users should not need
    to use it.
  [behavior changes]
  * Changed behavior of the `markdown_attribute` extension, to bring
    it in line with PHP markdown extra and multimarkdown.  Setting
    `markdown="1"` on an outer tag affects all contained tags,
    recursively, until it is reversed with `markdown="0"` (#1378).
  * Revised markdown definition list syntax (#1429).  Both the reader
    and writer are affected.  This change brings pandoc's definition list
    syntax into alignment with that used in PHP markdown extra and
    multimarkdown (with the exception that pandoc is more flexible about
    the definition markers, allowing tildes as well as colons).  Lazily
    wrapped definitions are now allowed.  Blank space is required
    between list items.  The space before a definition is used to determine
    whether it is a paragraph or a "plain" element.  **WARNING: This change
    may break existing documents!**  Either check your documents for
    definition lists without blank space between items, or use
    `markdown+compact_definition_lists` for the old behavior.
  * `.numberLines` now works in fenced code blocks even if no language
    is given (#1287, jgm/highlighting-kate#40).
  * Improvements to `--filter`:
    + Don't search PATH for a filter with an explicit path.
    This fixed a bug wherein `--filter ./caps.py` would run `caps.py` from
    the system path, even if there was a `caps.py` in the working directory.
    + Respect shebang if filter is executable (#1389).
    + Don't print misleading error message.
    Previously pandoc would say that a filter was not found,
    even in a case where the filter had a syntax error.
  * HTML reader:
    + Parse `div` and `span` elements even without `--parse-raw`,
    provided `native_divs` and `native_spans` extensions are set.
    Motivation:  these now generate native pandoc Div and Span
    elements, not raw HTML.
    + Parse EPUB-specific elements if the `epub_html_exts`
    extension is enabled.  These include `switch`, `footnote`,
    `rearnote`, `noteref`.
  * Org reader:
    + Support for inline LaTeX.  Inline LaTeX is now accepted and parsed by the
    org-mode reader.  Both math symbols (like `\tau`) and LaTeX commands (like
    `\cite{Coffee}`), can be used without any further escaping (Albert
    Krewinkel).
  * Textile reader and writer:
    + The `raw_tex` extension is no longer set by default.  You can
    enable it with `textile+raw_tex`.
  * DocBook reader:
    + Support `equation`, `informalequation`, `inlineequation` elements with
    `mml:math` content.  This is converted into LaTeX and put into a Pandoc
    Math inline.
  * Revised `plain` output, largely following the style of Project
    Gutenberg:
    + Emphasis is rendered with `_underscores_`, strong emphasis
    with ALL CAPS.
    + Headings are rendered differently, with space to set them off,
    not with setext style underlines. Level 1 headers are ALL CAPS.
    + Math is rendered using unicode when possible, but without the
    distracting emphasis markers around variables.
    + Footnotes use a regular `[n]` style.
  * Markdown writer:
    + Horizontal rules are now a line across the whole page.
    + Prettier pipe tables.  Columns are now aligned  (#1323).
    + Respect the `raw_html` extension.  `pandoc -t markdown-raw_html`
    no longer emits any raw HTML, including span and div tags
    generated by Span and Div elements.
    + Use span with style for `SmallCaps` (#1360).
  * HTML writer:
    + Autolinks now have class `uri`, and email autolinks have class
    `email`, so they can be styled.
  * Docx writer:
    + Document formatting is carried over from `reference.docx`.
    This includes margins, page size, page orientation, header,
    and footer, including images in headers and footers.
    + Include abstract (if present) with `Abstract` style (#1451).
    + Include subtitle (if present) with `Subtitle` style, rather
    than tacking it on to the title (#1451).
  * Org writer:
    + Write empty span elements with an id attribute as org anchors.
    For example `Span ("uid",[],[]) []` becomes `<<uid>>`.
  * LaTeX writer:
    + Put table captions above tables, to match the conventional
    standard.  (Previously they appeared below tables.)
    + Use `\(..\)` instead of `$..$` for inline math (#1464).
    + Use `\nolinkurl` in email autolinks.  This allows them to be styled
    using `\urlstyle{tt}`.  Thanks to Ulrike Fischer for the solution.
    + Use `\textquotesingle` for `'` in inline code.  Otherwise we get
    curly quotes in the PDF output (#1364).
    + Use `\footnote<.>{..}` for notes in beamer, so that footnotes
    do not appear before the overlays in which their markers appear
    (#1525).
    + Don't produce a `\label{..}` for a Div or Span element.  Do produce
    a `\hyperdef{..}` (#1519).
  * EPUB writer:
    + If the metadata includes `page-progression-direction` (which can be
    `ltr` or `rtl`, the `page-progression-direction` attribute will
    be set in the EPUB spine (#1455).
  * Custom lua writers:
    + Custom writers now work with `--template`.
    + Removed HTML header scaffolding from `sample.lua`.
    + Made citation information available in lua writers.
  * `--normalize` and `Text.Pandoc.Shared.normalize` now consolidate
    adjacent `RawBlock`s when possible.
  [API changes]
  * Added `Text.Pandoc.Readers.Docx`, exporting `readDocx` (Jesse Rosenthal).
  * Added `Text.Pandoc.Readers.EPUB`, exporting `readEPUB` (Matthew
    Pickering).
  * Added `Text.Pandoc.Readers.Txt2Tags`, exporting `readTxt2Tags` (Matthew
    Pickering).
  * Added `Text.Pandoc.Writers.DokuWiki`, exporting `writeDokuWiki`
    (Clare Macrae).
  * Added `Text.Pandoc.Writers.Haddock`, exporting `writeHaddock`.
  * Added `Text.Pandoc.MediaBag`, exporting `MediaBag`, `lookupMedia`,
    `insertMedia`, `mediaDirectory`, `extractMediaBag`.  The docx and epub
    readers return a pair of a `Pandoc` document and a `MediaBag` with
    the media resources they contain.  This can be extracted using
    `--extract-media`.  Writers that incorporate media (PDF, Docx,
    ODT, EPUB, RTF, or HTML formats with `--self-contained`) will look
    for resources in the `MediaBag` generated by the reader, in addition to
    the file system or web.
  * `Text.Pandoc.Readers.TexMath`: Removed deprecated `readTeXMath`.
    Renamed `readTeXMath'` to `texMathToInlines`.
  * `Text.Pandoc`: Added `Reader` data type (Matthew Pickering).
    `readers` now associates names of readers with `Reader`
    structures.  This allows inclusion of readers, like the docx
    reader, that take binary rather than textual input.
  * `Text.Pandoc.Shared`:
    + Added `capitalize` (Artyom Kazak), and replaced uses of
    `map toUpper` (which give bad results for many languages).
    + Added `collapseFilePath`, which removes intermediate `.` and
    `..` from a path (Matthew Pickering).
    + Added `fetchItem'`, which works like `fetchItem` but searches
    a `MediaBag` before looking on the net or file system.
    + Added `withTempDir`.
    + Added `removeFormatting`.
    + Added `extractSpaces` (from HTML reader) and generalized its type
    so that it can be used by the docx reader (Matthew Pickering).
    + Added `ordNub`.
    + Added `normalizeInlines`, `normalizeBlocks`.
    + `normalize` is now `Pandoc -> Pandoc` instead of
    `Data a :: a -> a`.  Some users may need to change their uses of
    `normalize` to the newly exported `normalizeInlines` or
    `normalizeBlocks`.
  * `Text.Pandoc.Options`:
    + Added `writerMediaBag` to `WriterOptions`.
    + Removed deprecated and no longer used `readerStrict` in
    `ReaderOptions`.  This is handled by `readerExtensions` now.
    + Added `Ext_compact_definition_lists`.
    + Added `Ext_epub_html_exts`.
    + Added `Ext_native_divs` and `Ext_native_spans`.
    This allows users to turn off the default pandoc behavior of
    parsing contents of div and span tags in markdown and HTML
    as native pandoc Div blocks and Span inlines.
  * `Text.Pandoc.Parsing`:
    + Generalized `readWith` to `readWithM` (Matthew Pickering).
    + Export `runParserT` and `Stream` (Matthew Pickering).
    + Added `HasQuoteContext` type class (Matthew Pickering).
    + Generalized types of `mathInline`, `smartPunctuation`, `quoted`,
    `singleQuoted`, `doubleQuoted`, `failIfInQuoteContext`,
    `applyMacros` (Matthew Pickering).
    + Added custom `token` (Matthew Pickering).
    + Added `stateInHtmlBlock` to `ParserState`.  This is used to keep
    track of the ending tag we're waiting for when we're parsing inside
    HTML block tags.
    + Added `stateMarkdownAttribute` to `ParserState`. This is used
    to keep track of whether the markdown attribute has been set in
    an enclosing tag.
    + Generalized type of `registerHeader`, using new type classes
    `HasReaderOptions`, `HasIdentifierList`, `HasHeaderMap` (Matthew
    Pickering).  These allow certain common functions to be reused
    even in parsers that use custom state (instead of `ParserState`),
    such as the MediaWiki reader.
    + Moved `inlineMath`, `displayMath` from Markdown reader to Parsing,
    and generalized their types (Matthew Pickering).
  * `Text.Pandoc.Pretty`:
    + Added `nestle`.
    + Added `blanklines`, which guarantees a certain number of blank lines
    (and no more).
  [bug fixes]
  * Markdown reader:
    + Fixed parsing of indented code in list items.  Indented code
    at the beginning of a list item must be indented eight spaces
    from the margin (or edge of the container), or four spaces
    from the list marker, whichever is greater.
    + Fixed small bug in HTML parsing with `markdown_attribute`, which
    caused incorrect tag nesting for input like
    `<aside markdown="1">*hi*</aside>`.
    + Fixed regression with intraword underscores (#1121).
    + Improved parsing of inline links containing quote characters (#1534).
    + Slight rewrite of `enclosure`/`emphOrStrong` code.
    + Revamped raw HTML block parsing in markdown (#1330).
    We no longer include trailing spaces and newlines in the
    raw blocks.  We look for closing tags for elements (but without
    backtracking).  Each block-level tag is its own `RawBlock`;
    we no longer try to consolidate them (though `--normalize` will do so).
    + Combine consecutive latex environments.  This helps when you have
    two minipages which can't have blank lines between them (#690, #1196).
    + Support smallcaps through span.
    `<span style="font-variant:small-caps;">foo</span>` will be
    parsed as a `SmallCaps` inline, and will work in all output
    formats that support small caps (#1360).
    + Prevent spurious line breaks after list items (#1137).  When the
    `hard_line_breaks` option was specified, pandoc would formerly
    produce a spurious line break after a tight list item.
    + Fixed table parsing bug (#1333).
    + Handle `c++` and `objective-c` as language identifiers in
    github-style fenced blocks (#1318).
    + Inline math must have nonspace before final `$` (#1313).
  * LaTeX reader:
    + Handle comments at the end of tables.  This resolves the issue
    illustrated in <http://stackoverflow.com/questions/24009489>.
    + Correctly handle table rows with too few cells.  LaTeX seems to
    treat them as if they have empty cells at the end  (#241).
    + Handle leading/trailing spaces in `\emph` better.
    `\emph{ hi }` gets parsed as `[Space, Emph [Str "hi"], Space]`
    so that we don't get things like `* hi *` in markdown output.
    Also applies to `\textbf` and some other constructions (#1146).
    + Don't assume preamble doesn't contain environments (#1338).
    + Allow (and discard) optional argument for `\caption` (James Aspnes).
  * HTML reader:
    + Fixed major parsing problem with HTML tables.  Table cells were
    being combined into one cell (#1341).
    + Fixed performance issue with malformed HTML tables.
    We let a `</table>` tag close an open `<tr>` or `<td>` (#1167).
    + Allow space between `<col>` and `</col>`.
    + Added `audio` and `source` in `eitherBlockOrInline`.
    + Moved `video`, `svg`, `progress`, `script`, `noscript`, `svg` from
    `blockTags` to `eitherBlockOrInline`.
    + `map` and `object` were mistakenly in both lists; they have been removed
    from `blockTags`.
    + Ignore `DOCTYPE` and `xml` declarations.
  * MediaWiki reader:
    + Don't parse backslash escapes inside `<source>` (#1445).
    + Tightened up template parsing.
    The opening `{{` must be followed by an alphanumeric or `:`.
    This prevents the exponential slowdown in #1033.
    + Support "Bild" for images.
  * DocBook reader:
    + Better handle elements inside code environments.  Pandoc's document
    model does not allow structure inside code blocks, but at least this way
    we preserve the text (#1449).
    + Support `<?asciidoc-br?>` (#1236).
  * Textile reader:
    + Fixed list parsing. Lists can now start without an intervening
    blank line (#1513).
    + HTML block-level tags that do not start a line are parsed as
    inline HTML and do not interrupt paragraphs (as in RedCloth).
  * Org reader:
    + Make tildes create inline code (#1345).  Also relabeled `code` and
    `verbatim` parsers to accord with the org-mode manual.
    + Respect `:exports` header argument in code blocks (Craig Bosma).
    + Fixed tight lists with sublists (#1437).
  * EPUB writer:
    + Avoid excess whitespace in `nav.xhtml`.  This should improve
    TOC view in iBooks (#1392).
    + Fixed regression on cover image.
    In 1.12.4 and 1.12.4.2, the cover image would not appear properly,
    because the metadata id was not correct.  Now we derive the id from the
    actual cover image filename, which we preserve rather than using
    "cover-image."
    + Keep newlines between block elements.  This allows
    easier diff-ability (#1424).
    + Use `stringify` instead of custom `plainify`.
    + Use `renderTags'` for all tag rendering.  This properly handles tags
    that should be self-closing.  Previously `<hr/>` would appear in EPUB
    output as `<hr></hr>` (#1420).
    + Better handle HTML media tags.
    + Handle multiple dates with OPF `event` attributes.  Note: in EPUB3 we
    can have only one dc:date, so only the first one is used.
  * LaTeX writer:
    + Correctly handle figures in notes.  Notes can't contain figures in
    LaTeX, so we fake it to avoid an error  (#1053).
    + Fixed strikeout + highlighted code (#1294).
    Previously strikeout highlighted code caused an error.
  * ConTeXt writer:
    + Improved detection of autolinks with URLs containing escapes.
  * RTF writer:
    + Improved image embedding: `fetchItem'` is now used to get the
    images, and calculated image sizes are indicated in the RTF.
    + Avoid extra paragraph tags in metadata (#1421).
  * HTML writer:
    + Deactivate "incremental" inside slide speaker notes (#1394).
    + Don't include empty items in the table of contents for
    slide shows.  (These would result from creating a slide
    using a horizontal rule.)
  * MediaWiki writer:
    + Minor renaming of `st` prefixed names.
  * AsciiDoc writer:
    + Double up emphasis and strong emphasis markers in intraword
    contexts, as required by asciidoc (#1441).
  * Markdown writer:
    + Avoid wrapping that might start a list, blockquote, or header (#1013).
    + Use Span instead of (hackish) `SmallCaps` in `plainify`.
    + Don't use braced attributes for fenced code (#1416).
    If `Ext_fenced_code_attributes` is not set, the first class
    attribute will be printed after the opening fence as a bare word.
    + Separate adjacent lists of the same kind with an HTML comment (#1458).
  * PDF writer:
    + Fixed treatment of data uris for images (#1062).
  * Docx writer:
    + Use Compact style for empty table cells (#1353).
    Otherwise we get overly tall lines when there are empty
    table cells and the other cells are compact.
    + Create overrides per-image for `media/` in reference docx.
    This should be somewhat more robust and cover more types of images.
    + Improved `entryFromArchive` to avoid an unneeded parse.
    + Section numbering carries over from reference.docx (#1305).
    + Simplified `abstractNumId` numbering.  Instead of sequential numbering,
    we assign numbers based on the list marker styles.
  * `Text.Pandoc.Options`:
    + Removed `Ext_fenced_code_attributes` from `markdown_github`
    extensions.
  * `Text.Pandoc.ImageSize`:
    + Use default instead of failing if image size not found
    in exif header (#1358).
    + ignore unknown exif header tag rather than crashing.
    Some images seem to have tag type of 256, which was causing
    a runtime error.
  * `Text.Pandoc.Shared`:
    + `fetchItem`:  unescape URI encoding before reading local file (#1427).
    + `fetchItem`:  strip a fragment like `?#iefix` from the extension before
    doing mime lookup, to improve mime type guessing.
    + Improved logic of `fetchItem`:  absolute URIs are fetched from the net;
    other things are treated as relative URIs if `sourceURL` is `Just _`,
    otherwise as file paths on the local file system.
    + `fetchItem` now properly handles links without a protocol (#1477).
    + `fetchItem` now escapes characters not allowed in URIs before trying
    to parse the URIs.
    + Fixed runtime error with `compactify'DL` on certain lists (#1452).
  * `pandoc.hs`: Don't strip path off of `writerSourceURL`: the path is
    needed to resolve relative URLs when we fetch resources (#750).
  * `Text.Pandoc.Parsing`
    + Simplified `dash` and `ellipsis` (#1419).
    + Removed `(>>~)` in favor of the equivalent `(<*)` (Matthew Pickering).
    + Generalized functions to use `ParsecT` (Matthew Pickering).
    + Added `isbn` and `pmid` to list of recognized schemes (Matthew
    Pickering).
  [template changes]
  * Added haddock template.
  * EPUB3:  Added `type` attribute to `link` tags.  They are supposed to
    be "advisory" in HTML5, but kindlegen seems to require them.
  * EPUB3:  Put title page in section with `epub:type="titlepage"`.
  * LaTeX: Made `\subtitle` work properly (#1327).
  * LaTeX/Beamer: remove conditional around date (#1321).
  * LaTeX:  Added `lot` and `lof` variables, which can be set to
    get `\listoftables` and `\listoffigures` (#1407).  Note that
    these variables can be set at the command line with `-Vlot -Vlof`
    or in YAML metadata.
  [under the hood improvements]
  * Rewrote normalize for efficiency (#1385).
  * Rewrote Haddock reader to use `haddock-library` (#1346).
    + This brings pandoc's rendering of haddock markup in line
    with the new haddock.
    + Fixed line breaks in `@` code blocks.
    + alex and happy are no longer build-depends.
  * Added `Text.Pandoc.Compat.Directory` to allow building against
    different versions of the `directory` library.
  + Added `Text.Pandoc.Compat.Except` to allow building against
    different verions of `mtl`.
  * Code cleanup in some writers, using Reader monad to avoid
    passing options parameter around (Matej Kollar).
  * Improved readability in `pandoc.hs`.
  * Miscellaneous code cleanups (Artyom Kazak).
  * Avoid `import Prelude hiding (catch)` (#1309, thanks to Michael
    Thompson).
  * Changed `http-conduit` flag to `https`.  Depend on `http-client`
    and `http-client-tls` instead of `http-conduit`.  (Note:  pandoc still
    depends on `conduit` via `yaml`.)
  * Require `highlighting-kate >= 0.5.8.5` (#1271, #1317, Debian #753299).
    This change to highlighting-kate means that PHP fragments no longer need
    to start with `<?php`.  It also fixes a serious bug causing failures with
    ocaml and fsharp.
  * Require latest `texmath`.  This fixes `\tilde{E}` and allows
    `\left` to be used with `]`, `)` etc. (#1319), among many other
    improvements.
  * Require latest `zip-archive`.  This has fixes for unicode path names.
  * Added tests for plain writer.
  * `Text.Pandoc.Templates`:
    + Fail informatively on template syntax errors.
    With the move from parsec to attoparsec, we lost good error
    reporting.  In fact, since we weren't testing for end of input,
    malformed templates would fail silently.  Here we revert back to
    Parsec for better error messages.
    + Use `ordNub` (#1022).
  * Benchmarks:
    + Made benchmarks compile again (Artyom Kazak).
    + Fixed so that the failure of one benchmark does not prevent others
    from running (Artyom Kazak).
    + Use `nfIO` instead of the `getLength` trick to force full evaluation.
    + Changed benchmark to use only the test suite, so that benchmarks
    run more quickly.
  * Windows build script:
    + Use one install command for pandoc, pandoc-citeproc.
    + Force install of pandoc-citeproc.
  * `make_osx_package`:  Call zip file `pandoc-VERSION-osx.zip`.
    The zip should not be named `SOMETHING.pkg.zip`, or OSX finder
    will extract it into a folder named `SOMETHING.pkg`, which it
    will interpret as a defective package (#1308).
  * `README`:
    + Made headers for all extensions so they have IDs and can be
    linked to (Beni Cherniavsky-Paskin).
    + Fixed typos (Phillip Alday).
    + Fixed documentation of attributes (#1315).
    + Clarified documentation on small caps (#1360).
    + Better documentation for `fenced_code_attributes` extension
    (Caleb McDaniel).
    + Documented fact that you can put YAML metadata in a separate file
    (#1412).
  pandoc (1.12.4.2)
  =================
  * Shared:  `addMetaValue` now behaves slightly differently:
    if both the new and old values are lists, it concatenates their
    contents to form a new list.
  * LaTeX reader:
    + Set `bibliography` in metadata from `\bibliography` or
    `\addbibresource` command.
    + Don't error on `%%foo` with no trailing newline.
  * Org reader:
    + Support code block headers (`#+BEGIN_SRC ...`) (Albert Krewinkel).
    + Fix parsing of blank lines within blocks (Albert Krewinkel).
    + Support pandoc citation extension (Albert Krewinkel).  This can
    be turned off by specifying `org-citations` as the input format.
  * Markdown reader:
    + `citeKey` moved to `Text.Pandoc.Parsing` so it can be used by
    other readers (Albert Krewinkel).
  * `Text.Pandoc.Parsing`:
    + Added `citeKey` (see above).
    + Added `HasLastStrPosition` type class and `updateLastStrPos`
    and `notAfterString` functions.
  * Updated copyright notices (Albert Krewinkel).
  * Added default.icml to data files so it installs with the package.
  pandoc (1.12.4)
  ===============
  * Made it possible to run filters that aren't executable (#1096).
    Pandoc first tries to find the executable (searching the path
    if path isn't given).  If it fails, but the file exists and has
    a `.py`, `.pl`, `.rb`, `.hs`, or `.php` extension, pandoc runs the filter
    using the appropriate interpreter.  This should make it easier to
    use filters on Windows, and make it more convenient for everyone.
  * Added Emacs org-mode reader (Albert Krewinkel).
  * Added InDesign ICML Writer (mb21).
  * MediaWiki reader:
    + Accept image links in more languages (Jaime Marquínez Ferrándiz).
    + Fixed bug in certain nested lists (#1213).  If a level 2 list was
    followed by a level 1 list, the first item of the level 1 list
    would be lost.
    + Handle table rows containing just an HTML comment (#1230).
  * LaTeX reader:
    + Give better location information on errors, pointing to line
    numbers within included files (#1274).
    + LaTeX reader:  Better handling of `table` environment (#1204).
    Positioning options no longer rendered verbatim.
    + Better handling of figure and table with caption (#1204).
    + Handle `@{}` and `p{length}` in tabular.  The length is not actually
    recorded, but at least we get a table (#1180).
    + Properly handle `\nocite`.  It now adds a `nocite` metadata
    field.  Citations there will appear in the bibliography but not
    in the text (unless you explicitly put a `$nocite$` variable
    in your template).
  * Markdown reader:
    + Ensure that whole numbers in YAML metadata are rendered without
    decimal points.  (This became necessary with changes to aeson
    and yaml libraries.  aeson >= 0.7 and yaml >= 0.8.8.2 are now required.)
    + Fixed regression on line breaks in strict mode (#1203).
    + Small efficiency improvements.
    + Improved parsing of nested `div`s.  Formerly a closing `div` tag
    would be missed if it came right after other block-level tags.
    + Avoid backtracking when closing `</div>` not found.
    + Fixed bug in reference link parsing in `markdown_mmd`.
    + Fixed a bug in list parsing (#1154).  When reading a raw list
    item, we now strip off up to 4 spaces.
    + Fixed parsing of empty reference link definitions (#1186).
    + Made one-column pipe tables work (#1218).
  * Textile reader:
    + Better support for attributes.  Instead of being ignored, attributes
    are now parsed and included in Span inlines.  The output will be a bit
    different from stock textile: e.g. for `*(foo)hi*`, we'll get
    `<em><span class="foo">hi</span></em>` instead of
    `<em class="foo">hi</em>`.  But at least the data is not lost.
    + Improved treatment of HTML spans (%%) (#1115).
    + Improved link parsing.  In particular we now pick up on attributes.
    Since pandoc links can't have attributes, we enclose the whole link in
    a span if there are attributes (#1008).
    + Implemented correct parsing rules for inline markup (#1175, Matthew
    Pickering).
    + Use Builder (Matthew Pickering).
    + Fixed list parsing bug (#1500).
    + Don't allow inline formatting to extend over newlines.
    This matches the behavior of RedCarpet, avoids some ugly bugs,
    and improves performance.
  * DocBook reader:
    + Better treatment of `formalpara`.  We now emit the title (if present)
    as a separate paragraph with boldface text (#1215).
    + Set metadata `author` not `authors`.
    + Added recognition of `authorgroup` and `releaseinfo` elements (#1214,
    Matthew Pickering).
    + Converted current meta information parsing in DocBook to a more
    extensible version which is aware of the more recent meta
    representation (Matthew Pickering).
  * HTML reader:
    + Require tagsoup 0.13.1, to fix a bug with parsing of script tags
    (#1248).
    + Treat processing instructions & declarations as block.  Previously
    these were treated as inline, and included in paragraph tags in HTML
    or DocBook output, which is generally not what is wanted (#1233).
    + Updated `closes` with rules from HTML5 spec.
    + Use Builder (Matthew Pickering, #1162).
  * RST reader:
    + Remove duplicate `http` in PEP links (Albert Krewinkel).
    + Make rst figures true figures (#1168, CasperVector)
    + Enhanced Pandoc's support for rST roles (Merijn Verstaaten).
    rST parser now supports: all built-in rST roles, new role definition,
    role inheritance, though with some limitations.
    + Use `author` rather than `authors` in metadata.
    + Better handling of directives.  We now correctly handle field
    lists that are indented more than three spaces.  We treat an
    `aafig` directive as a code block with attributes, so it can be
    processed in a filter (#1212).
  * LaTeX writer:
    + Mark span contents with label if span has an ID (Albert Krewinkel).
    + Made `--toc-depth` work well with books in latex/pdf output (#1210).
    + Handle line breaks in simple table cells (#1217).
    + Workaround for level 4-5 headers in quotes.  These previously produced
    invalid LaTeX: `\paragraph` or `\subparagraph` in a `quote` environment.
    This adds an `mbox{}` in these contexts to work around the problem.
    See <http://tex.stackexchange.com/a/169833/22451> (#1221).
    + Use `\/` to avoid en-dash ligature instead of `-{}-` (Vaclav Zeman).
    This is to fix LuaLaTeX output. The `-{}-` sequence does not avoid the
    ligature with LuaLaTeX but `\/` does.
    + Fixed string escaping in `hyperref` and `hyperdef` (#1130).
  * ConTeXt writer:  Improved autolinks (#1270).
  * DocBook writer:
    + Improve handling of hard line breaks in Docbook writer
    (Neil Mayhew).  Use a `<literallayout>` for the entire paragraph, not
    just for the newline character.
    + Don't let line breaks inside footnotes influence the enclosing
    paragraph (Neil Mayhew).
    + Distinguish tight and loose lists in DocBook output, using
    `spacing="compact"` (Neil Mayhew, #1250).
  * Docx writer:  When needed files are not present in the user's
    `reference.docx`, fall back on the versions in the `reference.docx`
    in pandoc's data files. This fixes a bug that occurs when a
    `reference.docx` saved by LibreOffice is used. (#1185)
  * EPUB writer:
    + Include extension in epub ids.  This fixes a problem with duplicate
    extensions for fonts and images with the same base name but different
    extensions (#1254).
    + Handle files linked in raw `img` tags (#1170).
    + Handle media in `audio` source tags (#1170).
    Note that we now use a `media` directory rather than `images`.
    + Incorporate files linked in `video` tags (#1170).  `src` and `poster`
    will both be incorporated into `content.opf` and the epub container.
  * HTML writer:
    + Add colgroup around col tags (#877).  Also affects EPUB writer.
    + Fixed bug with unnumbered section headings.  Unnumbered section
    headings (with class `unnumbered`) were getting numbers.
    + Improved detection of image links. Previously image links with
    queries were not recognized, causing `<embed>` to be used instead
    of `<img>`.
  * Man writer:  Ensure that terms in definition lists aren't line wrapped
    (#1195).
  * Markdown writer:
    + Use proper escapes to avoid unwanted lists (#980).  Previously we used
    0-width spaces, an ugly hack.
    + Use longer backtick fences if needed (#1206).  If the content contains a
    backtick fence and there are attributes, make sure longer fences are
    used to delimit the code.  Note:  This works well in pandoc, but github
    markdown is more limited, and will interpret the first string of three
    or more backticks as ending the code block.
  * RST writer:  Avoid stack overflow with certain tables (#1197).
  * RTF writer:  Fixed table cells containing paragraphs.
  * Custom writer:
    + Correctly handle UTF-8 in custom lua scripts (#1189).
    + Fix bugs with lua scripts with mixed-case filenames and
    paths containing `+` or `-` (#1267).  Note that `getWriter`
    in `Text.Pandoc` no longer returns a custom writer on input
    `foo.lua`.
  * AsciiDoc writer:  Handle multiblock and empty table cells
    (#1245, #1246).  Added tests.
  * `Text.Pandoc.Options`: Added `readerTrace` to `ReaderOptions`
  * `Text.Pandoc.Shared`:
    + Added `compactify'DL` (formerly in markdown reader) (Albert Krewinkel).
    + Fixed bug in `toRomanNumeral`:  numbers ending with '9' would
    be rendered as Roman numerals ending with 'IXIV' (#1249).  Thanks to
    Jesse Rosenthal.
    + `openURL`: set proxy with value of http_proxy env variable (#1211).
    Note:  proxies with non-root paths are not supported, due to
    limitations in `http-conduit`.
  * `Text.Pandoc.PDF`:
    + Ensure that temp directories deleted on Windows (#1192).  The PDF is
    now read as a strict bytestring, ensuring that process ownership will
    be terminated, so the temp directory can be deleted.
    + Use `/` as path separators in a few places, even on Windows.
    This seems to be necessary for texlive (#1151, thanks to Tim Lin).
    + Use `;` for `TEXINPUTS` separator on Windows (#1151).
    + Changes to error reporting, to handle non-UTF8 error output.
  * `Text.Pandoc.Templates`:
    + Removed unneeded datatype context (Merijn Verstraaten).
    + YAML objects resolve to "true" in conditionals (#1133).
    Note:  If `address` is a YAML object and you just have `$address$`
    in your template, the word `true` will appear, which may be
    unexpected.  (Previously nothing would appear.)
  * `Text.Pandoc.SelfContained`:
    + `mkSelfContained` now takes just two arguments, `WriterOptions` and
    the string.
  * It no longer looks in data files.  This only made sense when we
    had copies of slidy and S5 code there.
  * `fetchItem'` is used instead of the nearly duplicate `getItem`.
    + Handle `poster` attribute in `video` tags (#1188).
  * `Text.Pandoc.Parsing`:
    + Made `F` an instance of Applicative (#1138).
    + Added `stateCaption`.
    + Added `HasMacros`, simplified other typeclasses.
    Removed `updateHeaderMap`, `setHeaderMap`, `getHeaderMap`,
    `updateIdentifierList`, `setIdentifierList`, `getIdentifierList`.
    + Changed the smart punctuation parser to return `Inlines`
    rather than `Inline` (Matthew Pickering).
    + Changed `HasReaderOptions`, `HasHeaderMap`, `HasIdentifierList`
    from typeclasses of monads to typeclasses of states.  This simplifies
    the instance definitions and provides more flexibility.  Generalized
    type of `getOption` and added a default definition.  Removed
    `askReaderOption`.  Added `extractReaderOption`.  Added
    `extractHeaderMap` and `updateHeaderMap` in `HasHeaderMap`.
    Gave default definitions for `getHeaderMap`, `putHeaderMap`,
    `modifyHeaderMap`.  Added `extractIdentifierList` and
    `updateIdentifierList` in `HasIdentifierList`.  Gave defaults
    for `getIdentifierList`, `putIdentifierList`, and
    `modifyIdentifierList`.  The ultimate goal here is to allow different
    parsers to use their own, tailored parser states (instead of
    `ParserState`) while still using shared functions.
  * Template changes:
    + LaTeX template: Use `fontenc` package only with `pdflatex` (#1164).
    + LaTeX template:  Add `linestretch` and `fontfamily` variables.
    + LaTeX template:  Conditionalize author and date commands.
    + Beamer template: Consistent styles for figure and table captions
    (aaronwolen).
    + LaTeX and beamer template:  Adjust widths correctly for oversized
    images.  Use `\setkeys{Gin}{}` to set appropriate defaults for
    `\includegraphics` (Yihui Xie, Garrick Aden-Buie).  Load
    `upquote` only after `fontenc` (Yihui Xie).
    + Beamer template: Added caption package (#1200).
    + Beamer template:  changes for better unicode handling (KarolS).
    + DocBook template:  use `authorgroup` if there are authors.
    + revealjs template: Move `include-after` to end (certainlyakey).
    + revealjs template: Fixed PDF print function (#1220, kevinkenan).
  * Bumped version bounds of dependencies.
  * Added a `--trace` command line option, for debugging backtracking
    bugs.  So far this only works with the markdown reader.
  * MathMLinHTML:  Fixed deprecation warning (#362, gwern, Albert Krewinkel).
  * Updated travis script to test with multiple GHC versions.
  * Force failure of a Travis build if GHC produces warnings (Albert
    Krewinkel).
  * Add `.editorconfig` (Albert Krewinkel).
    See <http://editorconfig.org/> for details.
  * Give more useful error message if '-t pdf' is specified (#1155).
  * Added `Cite`, `SmallCaps` to `Arbitrary` instance (#1269).
  * Allow `html4` as a synonym of `html` as a reader (it already works
    as a writer).
  * README:
    + Added an explanation of how to use YAML metadata to
    force items to appear in the bibliography without citations in
    the text (like LaTeX `\nocite`).
    + Added note to `--bibtex/--natbib`: not for use in making PDF
    (#1194, thanks to nahoj).
    + Added explanatory notes about `--natbib` and `--biblatex`.
    + Added specification of legal syntax for citation keys.
    + Fixed variable defaults documentation (Albert Krewinkel).
  * Removed copyright statements for files that have been removed
    (Albert Krewinkel).
  * Moved some doc files from `data-files` to `extra-source-files` (#1123).
    They aren't needed at runtime.  We keep README and COPYRIGHT in data
    to ensure that they'll be available on all systems on which pandoc
    is installed.
* Thu Mar 27 2014 sbahling@suse.com
- Correct package license
* Sun Mar 16 2014 sbahling@suse.com
- update to 1.12.3.3
- Remove zip-archive-upper-bound.patch (fix integrated)
  Pandoc Changes:
  1.12.3.3
  ========
  * To changes to source; recompiled tarball with latest alex and
    happy, so they will work with GHC 7.8.
  1.12.3.2
  ========
  * Bumped version bounds for blaze-html, blaze-markup.
  * ImageSize:  Avoid use of lookAhead, which is not in binary >= 0.6
    (#1124).
  * Fixed mediawiki ordered list parsing (#1122).
  * HTML reader:  Fixed bug reading inline math with `$$` (#225).
  * Added support for LaTeX style literate Haskell code blocks in rST
    (Merijn Verstraaten)
  1.12.3.1
  ========
  * Relaxed version constraint on binary, allowing the use of binary 0.5.
  1.12.3
  ======
  * The `--bibliography` option now sets the `biblio-files` variable.
    So, if you're using `--natbib` or `--biblatex`, you can just use
    `--bibliography=foo.bib` instead of `-V bibliofiles=foo`.
  * Don't run pandoc-citeproc filter if `--bibliography` is
    used together with `--natbib` or `--biblatex` (Florian Eitel).
  * Template changes:
    + Updated beamer template to include booktabs.
    + Added `abstract` variable to LaTeX template.
    + Put `header-includes` after `title` in LaTeX template (#908).
    + Allow use of `\includegraphics[size]` in beamer.
    This just required porting a macro definition from the default
    LaTeX template to the default beamer template.
  * `reference.docx`:  Include `FootnoteText` style.
    Otherwise Word ignores the style, even when specified in the `pPr`.
    (#901)
  * `reference.odt`:  Tidied `styles.xml`.
  * Relaxed version bounds for dependencies.
  * Added `withSocketsDo` around http conduit code in `openURL`,
    so it works on Windows (#1080).
  * Added `Cite` function to `sample.lua`.
  * Markdown reader:
    + Fixed regression in title blocks (#1089).
    If author field was empty, date was being ignored.
    + Allow backslash-newline hard line breaks in grid and
    multiline table cells.
    + Citation keys may now start with underscores, and may contain
    underscores adjacent to internal punctuation.
  * LaTeX reader:
    + Add support for `Verb` macro (jrnold) (#1090).
    + Support babel-style quoting: `` "`..."' ``.
  * Properly handle script blocks in strict mode.  (That is,
    `markdown-markdown_in_html_blocks`.) Previously a spurious
    `<p>` tag was being added (#1093).
  * Docbook reader: Avoid failure if `tbody` contains no `tr` or `row`
    elements.
  * LaTeX writer:
    + Factored out function for table cell creation.
    + Better treatment of footnotes in tables.
    Notes now appear in the regular sequence, rather than in the
    table cell.  (This was a regression in 1.10.)
  * HTML reader: Parse name/content pairs from meta tags as metadata.
    Closes #1106.
  * Moved `fixDisplayMath` from Docx writer to `Writer.Shared`.
  * OpenDocument writer:  Fixed `RawInline`, `RawBlock` so they don't escape.
  * ODT writer:  Use mathml for proper rendering of formulas.
    Note:  LibreOffice's support for this seems a bit buggy.  But
    it should be better than what we had before.
  * RST writer: Ensure no blank line after def in definition list (#992).
  * Markdown writer: Don't use tilde code blocks with braced attributes in
    `markdown_github` output.  A consequence of this change is that the
    backtick form will be preferred in general if both are enabled.  That
    is good, as it is much more widespread than the tilde form.  (#1084)
  * Docx writer:  Fixed problem with some modified reference docx files.
    Include `word/_rels/settings.xml.rels` if it exists, as well as other
    `rels` files besides the ones pandoc generates explicitly.
  * HTML writer:
    + With `--toc`, headers no longer link to themselves (#1081).
    + Omit footnotes from TOC entries.  Otherwise we get doubled
    footnotes when headers have notes!
  * EPUB writer:
    + Avoid duplicate notes when headings contain notes.
    This arose because the headings are copied into the metadata
    "title" field, and the note gets rendered twice.  We strip the
    note now before putting the heading in "title".
    + Strip out footnotes from toc entries.
    + Fixed bug with `--epub-stylesheet`.  Now the contents of
    `writerEpubStylesheet` (set by `--epub-stylesheet`)
    should again work, and take precedence over a stylesheet specified
    in the metadata.
  * `Text.Pandoc.Pretty`:  Added `nestle`.  API change.
  * `Text.Pandoc.MIME`: Added `wmf`, `emf`.
  * `Text.Pandoc.Shared`:  `fetchItem` now handles image URLs beginning
    with `//`.
  * `Text.Pandoc.ImageSize`:  Parse EXIF format JPEGs.  Previously
    we could only get size information for JFIF format, which led
    to squished images in Word documents. Closes #976.
  * Removed old `MarkdownTest_1.0.3` directory (#1104).
* Tue Dec 31 2013 peter.trommler@ohm-hochschule.de
- update to 1.12.2.1
- add zip-archive-upper-bound.patch
  * relax version constraint on ghc-zip-archive so we can avoid
  a dependency on ghc-utf8-string, which is not in Factory
  * see upstream commit 26052d3
  * can be dropped with next upstream release
* Sun Dec 29 2013 peter.trommler@ohm-hochschule.de
- expand macro in name tag, OBS requirement
* Sun Dec 29 2013 peter.trommler@ohm-hochschule.de
- merge d:l:haskell changes
* Mon Oct  7 2013 sbahling@suse.com
- Update to 1.12.0.2
- Use %%fdupes to make rpmlint happy
- Move documentation from /usr/share/pandoc-%%version to standard docdir
  Pandoc New Features:
  * Much more flexible metadata using YAML metadata.
  * Added opml (OPML) as input and output format.
  * Added haddock (Haddock markup) as input format
  * Added revealjs output format, for reveal.js HTML 5 slide shows.
  * Custom writers can now be written in lua.
  * New --filter/-F option to make it easier to run “filters”
  * Added --metadata/-M option.
  * Added --print-default-data-file
  * Added syntax for “pauses” in slide shows.
  * New markdown extensions:
  - ignore_line_breaks
  - yaml_metadata_block
  - ascii_identifiers
  - lists_without_preceding_blankline
* Sat May 18 2013 peter.trommler@ohm-hochschule.de
- add manual pages to files
- remove man page helper program that was added by cabal-rpm
* Sat May 18 2013 peter.trommler@ohm-hochschule.de
- update to 1.11.1 from upstream
  * hide some APIs: Parsing, Highlighting
  * new input format markdown_github
  * see http://johnmacfarlane.net/pandoc/releases.html
  for fixes
* Mon Mar 11 2013 peter.trommler@ohm-hochschule.de
- fix rpath in pandoc executable
* Fri Jan 25 2013 peter.trommler@ohm-hochschule.de
- update to 1.10.0.5 from upstream
  * new input format MediaWiki
  * new Output formats EPUB3, FictionBooks2
  * see http://johnmacfarlane.net/pandoc/releases.html
  for complete list of new features and fixes
* Sun Nov 18 2012 peter.trommler@ohm-hochschule.de
- update to 1.9.4.5 from upstream
  pandoc (1.9.4.5)
  * Raised version bounds on network, base64-bytestring, json,
    and template-haskell.
  pandoc (1.9.4.4)
  * Removed `tests` flag and made test suite into a proper cabal
    test suite, which can now be enabled using `--enable-tests`
    and run with `cabal test`.
  * Moved man page creation out of `Setup.hs` and into an
    executable built by Cabal, but never installed.  This
    allows dependencies to be specified, and solves a problem
    with 1.9.4.3, which could only be installed if `data-default`
    had already been installed.
  * Updated `lhs-latex.tex` test for latest highlighting-kate
    representation of backticks.
  pandoc (1.9.4.3)
  * Removed `-threaded` from default compile flags.
  * Modified modules to compile with GHC 7.6 and latest version of time
    package.
* Thu Jul  5 2012 peter.trommler@ohm-hochschule.de
- update to 1.9.4.2 from upstream
  * Don't encode/decode file paths if base >= 4.4.
    Prior to base 4.4, filepaths and command line arguments were treated
    as unencoded lists of bytes, not unicode strings, so we had to work
    around that by encoding and decoding them. This commit adds CPP
    checks for the base version that intelligibly enable encoding/decoding
    when needed. Fixes a bug with multilingual filenames when pandoc was
    compiled with ghc 7.4 (#540).
  * Don't generate an empty H1 after hrule slide breaks.
    We now use a slide-level header with contents `[Str "\0"]` to mark
    an hrule break.  This avoids creation of an empty H1 in these
    contexts.  Closes #484.
  * Docbook reader: Added support for "bold" emphasis.  Thanks to mb21.
  * In make_osx_package.sh, ensure citeproc-hs is built with the
    embed_data_files flag.
  * MediaWiki writer: Avoid extra blank lines after sublists (Gavin Beatty).
  * ConTeXt writer: Don't escape `&`, `^`, `<`, `>`, `_`,
    simplified escapes for `}` and `{` to `\{` and `\}` (Aditya Mahajan).
  * Fixed handling of absolute URLs in CSS imports with `--self-contained`.
    Closes #535.
  * Added webm to mime types. Closes #543.
  * Added some missing exports and tests to the cabal file
    (Alexander V Vershilov).
  * Compile with `-rtsopts` and `-threaded` by default.
* Sat Jun 16 2012 peter.trommler@ohm-hochschule.de
- update to 1.9.4.1 from upstream
  pandoc (1.9.4.1)
  * Markdown reader: Added `cf.` and `cp.` to list of likely abbreviations.
  * LaTeX template: Added `linkcolor`, `urlcolor` and `links-as-notes`
    variables.  Make TOC links black.
  * LaTeX template improvements.
    + Don't print date unless one is given explicitly in the document.
    + Simplified templates.
    + Use fontenc [T1] by default, and lmodern.
    + Use microtype if available.
  * Biblio:
    + Add comma to beginning of bare suffix, e.g. `@item1 [50]`.
    Motivation: `@item1 [50]` should be as close as possible to
    `[@item1, 50]`.
    + Added workaround for a bug in citeproc-hs 0.3.4 that causes footnotes
    beginning with a citation to be empty.  Closes #531.
  * Fixed documentation on mixed lists.  Closes #533.
  pandoc (1.9.4)
  * Simplified `Text.Pandoc.Biblio` and fixed bugs with citations inside
    footnotes and captions.  We now handle note citations by inserting
    footnotes during initial citation processing, and doing a separate
    pass later to remove notes inside notes.
  * Added 'zenburn' highlight style from highlighting-kate.
  * Added Slideous writer. Slideous is an HTML + javascript slide show
    format, similar to Slidy, but works with IE 7. (Jonas Smedegaard)
  * LaTeX writer:
    + Ensure we don't have extra blank lines at ends of cells.
    This can cause LaTeX errors, as they are interpreted as new paragraphs.
    + More consistent interblock spacing.
    + Require highlighting-kate >= 0.5.1, for proper highlighted inline
    code in LaTeX.  Closes #527.
    + Ensure that a Verbatim at the end of a footnote is followed by
    a newline. (Fixes a regression in the previous version.)
    + In default template, use black for internal links and TOC.
    Added commented-out code to use footnotes for links, as would
    be suitable in print output.
  * Beamer writer:  When `--incremental` is used, lists inside
    a block quote should appear all at once.  (This makes Beamer
    output consistent with the HTML slide show formats.)
  * ConTeXt writer:
    + Escape `%%` as `\letterpercent{}` not `\letterpercent `,
    to avoid gobbling spaces after the `%%` sign.
    + Ensure space after `\stopformula`.
  * Markdown writer:
    + Use `:` form instead of `~` in definition lists, for better
    compatibility with other markdown implementations.
    + Don't wrap the term, because it breaks definition lists.
    + Use a nonzero space to prevent false recognition
    of list marker in ordered lists.  Closes #516.
  * Org writer: Add space before language name.  Closes #523.
  * Docx writer: Simplified bullet characters so they work properly
    with Word 2007. Closes #520.
  * LaTeX reader: Support `\centerline`.
  * RST reader:  handle figures.  Closes #522.
  * Textile reader: fix for `<notextile>` and `==`.  Closes #517.
    (Paul Rivier)
* Thu Jun  7 2012 peter.trommler@ohm-hochschule.de
- update to 1.9.3 from upstream
  pandoc (1.9.3)
  * Fixed bug in `fromEntities`.  The previous version would turn
    `hi & low you know;` into `hi &`.
  * HTML reader:
    + Don't skip nonbreaking spaces.
    Previously a paragraph containing just `&nbsp;` would be rendered
    as an empty paragraph. Thanks to Paul Vorbach for pointing out the bug.
    + Support `<col>` and `<caption>` in tables. Closes #486.
  * Markdown reader:
    + Don't recognize references inside delimited code blocks.
    + Allow list items to begin with lists.
  * Added basic docbook reader (John MacFarlane and Mauro Bieg).
  * LaTeX reader:
    + Handle `\bgroup`, `\egroup`, `\begingroup`, `\endgroup`.
    + Control sequences can't be followed by a letter.
    This fixes a bug where `\begingroup` was parsed as `\begin`
    followed by `group`.
    + Parse 'dimension' arguments to unknown commands.  e.g. `\parindent0pt`
    + Make `\label` and `\ref` sensitive to `--parse-raw`.
    If `--parse-raw` is selected, these will be parsed as raw latex
    inlines, rather than bracketed text.
    + Don't crash on unknown block commands (like `\vspace{10pt}`)
    inside `\author`; just skip them.  Closes #505.
  * Textile reader:
    + Implemented literal escapes with `==` and `<notextile>`.  Closes #473.
    + Added support for LaTeX blocks and inlines (Paul Rivier).
    + Better conformance to RedCloth inline parsing (Paul Rivier).
    + Parse '+text+' as emphasized (should be underlined, but this
    is better than leaving literal plus characters in the output.
  * Docx writer: Fixed multi-paragraph list items.  Previously they each
    got a list marker.  Closes #457.
  * LaTeX writer:
    + Added `--no-tex-ligatures` option to avoid replacing
    quotation marks and dashes with TeX ligatures.
    + Use `fixltx2e` package to provide '\textsubscript'.
    + Improve spacing around LaTeX block environments:
    quote, verbatim, itemize, description, enumerate.
    Closes #502.
    + Use blue instead of pink for URL links in latex/pdf output.
  * ConTeXt writer: Fixed escaping of `%%`.
    In text, `%%` needs to be escaped as `\letterpercent`, not `\%%`
    Inside URLs, `%%` needs to be escaped as `\%%`
    Thanks to jmarca and adityam for the fix.  Closes #492.
  * Texinfo writer:  Escape special characters in node titles.
    This fixes a problem pointed out by Joost Kremers.  Pandoc used
    to escape an '@' in a chapter title, but not in the corresponding
    node title, leading to invalid texinfo.
  * Fixed document encoding in texinfo template.
    Resolves Debian Bug #667816.
  * Markdown writer:
    + Don't force delimited code blocks to be flush left.
    Fixes bug with delimited code blocks inside lists etc.
    + Escape `<` and `$`.
  * LaTeX writer: Use `\hyperref[ident]{text}` for internal links.
    Previously we used `\href{\#ident}{text}`, which didn't work on
    all systems. Thanks to Dirk Laurie.
  * RST writer: Don't wrap link references.  Closes #487.
  * Updated to use latest versions of blaze-html, mtl.
  pandoc (1.9.2)
  * LaTeX reader:
    + Made `lstlisting` work as a proper verbatim environment.
    + Fixed bug parsing LaTeX tables with one column.
  * LaTeX writer:
    + Use `{}` around `ctable` caption, so that formatting can be used.
    + Don't require eurosym package unless document has a €.
  * LaTeX template: Added variables for `geometry`, `romanfont`,
    `sansfont`, `mathfont`, `mainfont` so users can more easily
    customize fonts.
  * PDF writer:
    + Run latex engine at least two times, to ensure
    that PDFs will have hyperlinked bookmarks.
    + Added PDF metadata (title,author) in LaTeX standalone + PDF output.
  * Texinfo writer: retain directories in image paths.  (Peter Wang)
  * RST writer:  Better handling of inline formatting, in accord
    with docutils' "inline markup recognition rules" (though we don't
    implement the unicode rules fully). Now `hi*there*hi` gets
    rendered properly as `hi\ *there*\ hi`, and unnecessary
    `\ ` are avoided around `:math:`, `:sub:`, `:sup:`.
  * RST reader:
    + Parse `\ ` as null, not escaped space.
    + Allow `` :math:`...` `` even when not followed by blank
    or `\`.  This does not implement the complex rule docutils follows,
    but it should be good enough for most purposes.
    + Add support for the rST default-role directive. (Greg Maslov)
  * Text.Pandoc.Parsing: Added `stateRstDefaultRole` field to `ParserState`.
    (Greg Maslov)
  * Markdown reader: Properly handle citations nested in other inline
    elements.
  * Markdown writer:  don't replace empty alt in image with "image".
  * DZSlides:  Updated template.html and styles in default template.
    Removed bizarre CSS for `q` in dzslides template.
  * Avoid repeated `id` attribute in section and header in HTML slides.
  * README improvements:  new instructions on internal links,
    removed misleading note on reST math.
  * Build system:
    + Fixed Windows installer so that dzslides works.
    + Removed stripansi.sh.
    + Added .travis.yml for Travis continuous integration support..
    + Fixed upper bound for zlib (Sergei Trofimovich).
    + Fixed upper bound for test-framework.
    + Updated haddocks for haddock-2.10 (Sergei Trofimovich).
- update needed for Haskell Platform 2012.2.0.0
* Mon May 14 2012 peter.trommler@ohm-hochschule.de
- remove docdir to prevent double packaging (fails in Factory)
* Mon May 14 2012 peter.trommler@ohm-hochschule.de
- put docdir back
- fix dependencies for devel package (bnc #762003)
- fix packaging (bnc #713301)
* Sun Apr 29 2012 peter.trommler@ohm-hochschule.de
- exclude doc dir from library packages
* Sun Apr 29 2012 peter.trommler@ohm-hochschule.de
- simplified spec file
- add README and others to %%doc in main package (bnc #713301)
* Tue Mar 13 2012 peter.trommler@ohm-hochschule.de
- removed attr for man pages
- added filter for rpmlint (debuginfo)
* Mon Mar 12 2012 peter.trommler@ohm-hochschule.de
- upgrade to 1.9.1.2 from upstream (fixes man page issue)
* Fri Mar  9 2012 herbert@graeber-clan.de
- revert last change, because without_hscolour was already undefined
* Fri Mar  9 2012 mvancura@suse.de
- allow hscolour support as we are over the bootstrapping phase
* Fri Mar  9 2012 mvancura@suse.de
- man pages must have permissions 644
* Thu Jan 19 2012 herbert@graeber-clan.de
- initial packaging for Fedora automatically generated by cabal2spec-0.24.1
